@@ -1,21 +1,30 @@
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
+/*
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public License as
+ *  published by the Free Software Foundation; either version 3 of
+ *  the License, or (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details:
+ *
+ *  http://www.gnu.org/copyleft/gpl.txt
+ */
 
-#include <gtk/gtk.h>
 #include "callbacks.h"
-#include "interface.h"
-#include "support.h"
-#include "common.h"
 #include "shared.h"
 
 /* File variables */
-static GtkWidget *error_dialog = NULL;
-static GtkWidget *azel_dialog  = NULL;
-static GtkWidget *loc_dialog   = NULL;
+static GtkWidget *error_dialog  = NULL;
+static GtkWidget  *loc_dialog   = NULL;
+static GtkBuilder *loc_builder  = NULL;
+static GtkWidget  *azel_dialog  = NULL;
+static GtkBuilder *azel_builder = NULL;
 
 /* Popup menu */
-static GtkWidget *main_menu = NULL;
+static GtkWidget  *popup_menu    = NULL;
+static GtkBuilder *popup_builder = NULL;
 
 /*------------------------------------------------------------------------*/
 
@@ -27,67 +36,70 @@ static GtkWidget *main_menu = NULL;
 Error_Dialog( char *mesg, gboolean fatal )
 {
   GtkWidget *label;
+  GtkBuilder *builder;
 
   Clear_Mode( ALL_MODES );
-  if( error_dialog != NULL ) return;
-  error_dialog = create_error_dialog();
-  label = lookup_widget( error_dialog, "error_mesg" );
-  gtk_label_set_text( GTK_LABEL(label), mesg );
-  if( fatal )
+  if( !error_dialog )
   {
- 	GtkWidget *btn = lookup_widget( error_dialog, "error_ok" );
-	gtk_widget_hide( btn );
+	error_dialog = create_error_dialog( &builder );
+	label = Builder_Get_Object( builder, "error_mesg" );
+	gtk_label_set_text( GTK_LABEL(label), mesg );
+	if( fatal )
+	{
+	  GtkWidget *btn = Builder_Get_Object( builder, "error_ok" );
+	  gtk_widget_hide( btn );
+	}
+	gtk_widget_show( error_dialog );
+	g_object_unref( builder );
   }
-  gtk_widget_show( error_dialog );
 
-  GtkWidget *btn = lookup_widget( sat_track, "start_togglebutton" );
+  GtkWidget *btn = Builder_Get_Object(
+	  satellite_track_builder, "start_togglebutton" );
   gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(btn), FALSE );
 }
 
 
-void
-on_sat_track_destroy(
-	GtkObject       *object,
-	gpointer         user_data)
+  void
+on_satellite_track_destroy(
+	GObject       *object,
+	gpointer       user_data)
 {
   Cleanup();
   gtk_main_quit();
 }
 
 
-gboolean
-on_sat_track_delete_event(
+  gboolean
+on_satellite_track_delete_event(
 	GtkWidget       *widget,
 	GdkEvent        *event,
 	gpointer         user_data)
 {
   Clear_Mode( SINGLE_SAT );
-  return FALSE;
+  return( FALSE );
 }
 
 
-void
+  void
 on_txrx_track_toggled(
 	GtkToggleButton *togglebutton,
 	gpointer         user_data)
 {
-  GtkLabel *label = GTK_LABEL( lookup_widget(sat_track, "trk_status") );
-
   /* Enable/disable Rx/Tx tracking */
   if( gtk_toggle_button_get_active(togglebutton) )
   {
-	gtk_label_set_markup( label, TRACK_ON );
+	gtk_label_set_markup( GTK_LABEL(trk_status), TRACK_ON );
 	SetFlag( UPLNK_DNLNK_TRACK );
   }
   else
   {
-	gtk_label_set_markup( label, TRACK_OFF );
+	gtk_label_set_markup( GTK_LABEL(trk_status), TRACK_OFF );
 	ClearFlag( UPLNK_DNLNK_TRACK );
   }
 }
 
 
-void
+  void
 on_update_track_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
@@ -96,20 +108,21 @@ on_update_track_clicked(
 
   if( isFlagSet(CAT_SETUP) )
   {
-	gbl_tcvr_status.upl_dnl_offset =
-	  ( gbl_tcvr_status.flags & PASSBAND_NORM ?
-		(gbl_tcvr_status.uplink_freq - gbl_tcvr_status.dnlink_freq) :
-		(gbl_tcvr_status.uplink_freq + gbl_tcvr_status.dnlink_freq) );
+	transceiver_status.upl_dnl_offset =
+	  ( transceiver_status.flags & PASSBAND_NORM ?
+	  (transceiver_status.uplink_freq - transceiver_status.dnlink_freq) :
+	  (transceiver_status.uplink_freq + transceiver_status.dnlink_freq) );
 
 	SetFlag( UPLNK_DNLNK_TRACK );
 
-	tgbutton = GTK_TOGGLE_BUTTON(lookup_widget(sat_track, "txrx_track"));
+	tgbutton = GTK_TOGGLE_BUTTON(
+		Builder_Get_Object(satellite_track_builder, "txrx_track") );
 	gtk_toggle_button_set_active( tgbutton, TRUE );
   }
 }
 
 
-void
+  void
 on_doppler_corr_toggled(
 	GtkToggleButton *togglebutton,
 	gpointer         user_data)
@@ -127,7 +140,7 @@ on_doppler_corr_toggled(
 }
 
 
-void
+  void
 on_tcvr_cat_toggled(
 	GtkToggleButton *togglebutton,
 	gpointer         user_data)
@@ -138,7 +151,7 @@ on_tcvr_cat_toggled(
   /* Enable/disable cat control */
   if( gtk_toggle_button_get_active(togglebutton) )
   {
-	ret_str = Read_Transponder_Data( gbl_sat_status.name );
+	ret_str = Read_Transponder_Data( satellite_status.name );
 	if( strcmp(ret_str, "OK!") != 0 )
 	{
 	  Error_Dialog( ret_str, FATAL );
@@ -146,7 +159,7 @@ on_tcvr_cat_toggled(
 	}
 
 	if( !Open_Tcvr_Serial() ) return;
-	gbl_mode_idx = 0;
+	mode_index = 0;
 	if( !Initialize_Tcvr(DEFAULT_MODE) )
 	  return;
 
@@ -155,32 +168,28 @@ on_tcvr_cat_toggled(
 	else
 	  Set_Doppler_Label( DOPPLER_ON );
 
-	label = GTK_LABEL( lookup_widget(sat_track, "trk_status") );
 	if( isFlagSet(UPLNK_DNLNK_TRACK) )
-	  gtk_label_set_markup( label, TRACK_ON );
+	  gtk_label_set_markup( GTK_LABEL(trk_status), TRACK_ON );
 	else
-	  gtk_label_set_markup( label, TRACK_OFF );
+	  gtk_label_set_markup( GTK_LABEL(trk_status), TRACK_OFF );
   }
   else
   {
 	Close_Tcvr_Serial();
-	label = GTK_LABEL( lookup_widget(sat_track, "rx_dplr") );
+	label = GTK_LABEL( Builder_Get_Object(satellite_track_builder, "rx_dplr") );
 	gtk_label_set_text( label, _("Doppler") );
-	label = GTK_LABEL( lookup_widget(sat_track, "tx_dplr") );
+	label = GTK_LABEL( Builder_Get_Object(satellite_track_builder, "tx_dplr") );
 	gtk_label_set_text( label, _("Doppler") );
-	label = GTK_LABEL( lookup_widget(sat_track, "dop_status") );
-	gtk_label_set_text( label, _("Doppler") );
-	label = GTK_LABEL( lookup_widget(sat_track, "trk_status") );
-	gtk_label_set_text( label, _("Tx/Rx Track") );
-	label = GTK_LABEL( lookup_widget(sat_track, "cat_status") );
-	gtk_label_set_text( label, _("Enable CAT") );
+	gtk_label_set_text( GTK_LABEL(dop_status), _("Doppler") );
+	gtk_label_set_text( GTK_LABEL(trk_status), _("Tx/Rx Track") );
+	gtk_label_set_text( GTK_LABEL(cat_status), _("Enable CAT") );
 	gtk_button_set_label( GTK_BUTTON(
-		  lookup_widget(sat_track, "mode_chng")), _("Change Mode") );
+		  Builder_Get_Object(satellite_track_builder, "mode_chng")), _("Change Mode") );
   }
 }
 
 
-void
+  void
 on_rotor_control_toggled(
 	GtkToggleButton *togglebutton,
 	gpointer         user_data)
@@ -188,7 +197,7 @@ on_rotor_control_toggled(
   /* Enable/disable rotor control */
   if( gtk_toggle_button_get_active(togglebutton) )
 	Enable_Tracking();
-  else
+  else if( isFlagSet(ROTORS_ENABLED) )
   {
 	int azim_dir, elev_dir;
 
@@ -202,13 +211,14 @@ on_rotor_control_toggled(
 	Disable_Tracking();
 	ClearFlag( TRACKING_FLAGS );
 
-	gtk_label_set_text( GTK_LABEL(lookup_widget(sat_track, "rot_status")),
+	gtk_label_set_text( GTK_LABEL(
+		  Builder_Get_Object(satellite_track_builder, "rot_status")),
 		_("Enable Rotors") );
   }
 }
 
 
-void
+  void
 on_multi_sat_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
@@ -217,16 +227,20 @@ on_multi_sat_clicked(
 }
 
 
-void
+  void
 on_pass_pred_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
 {
-  Set_Mode( PASS_PRED );
+  if( isModeSet(XSATCOM_RUN) )
+  {
+	Pass_Predict_Mode( NULL );
+	Set_Mode( PASS_PRED );
+  }
 }
 
 
-void
+  void
 on_multi_loc_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
@@ -235,16 +249,20 @@ on_multi_loc_clicked(
 }
 
 
-void
+  void
 on_illum_pred_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
 {
-  Set_Mode( ILLUM_PRED );
+  if( isModeSet(XSATCOM_RUN) )
+  {
+	Illumination_Predict_Mode( NULL );
+	Set_Mode( ILLUM_PRED );
+  }
 }
 
 
-void
+  void
 on_xplanet_plot_toggled(
 	GtkToggleButton *togglebutton,
 	gpointer         user_data)
@@ -252,9 +270,9 @@ on_xplanet_plot_toggled(
   if( gtk_toggle_button_get_active(togglebutton) )
   {
 	SetFlag( XPLANET_PLOT );
-	if( gbl_xplanet == XPLANET_STOPPED )
+	if( xplanet == XPLANET_STOPPED )
 	{
-	  Config_Xplanet( &gbl_obs_status );
+	  Config_Xplanet( &observer_status );
 	}
   }
   else
@@ -264,7 +282,7 @@ on_xplanet_plot_toggled(
 	{
 	  if( system("pkill xplanet") == -1 )
 		fprintf( stderr, "xsatcom: system() function call failed\n" );
-	  gbl_xplanet = XPLANET_STOPPED;
+	  xplanet = XPLANET_STOPPED;
 	}
   }
 }
@@ -278,9 +296,9 @@ on_multisat_plot_toggled(
   if( gtk_toggle_button_get_active(togglebutton) )
   {
 	SetFlag( MULTISAT_PLOT );
-	if( gbl_xplanet == XPLANET_STOPPED )
+	if( xplanet == XPLANET_STOPPED )
 	{
-	  Config_Xplanet( &gbl_obs_status );
+	  Config_Xplanet( &observer_status );
 	}
   }
   else
@@ -290,57 +308,59 @@ on_multisat_plot_toggled(
 	{
 	  if( system("pkill xplanet") == -1 )
 		fprintf( stderr, "xsatcom: system() function call failed\n" );
-	  gbl_xplanet = XPLANET_STOPPED;
+	  xplanet = XPLANET_STOPPED;
 	}
   }
 }
 
 
-gboolean
-on_multi_sat_delete_event(
+  gboolean
+on_multi_satellite_delete_event(
 	GtkWidget       *widget,
 	GdkEvent        *event,
 	gpointer         user_data)
 {
   Set_Mode( END_MULTI_SAT );
-  return FALSE;
+  return( FALSE );
 }
 
 
-gboolean
-on_pass_pred_delete_event(
+  gboolean
+on_pass_predict_delete_event(
 	GtkWidget       *widget,
 	GdkEvent        *event,
 	gpointer         user_data)
 {
-  Set_Mode( END_PASS_PRED );
-  return FALSE;
+  while( g_main_context_iteration(NULL, FALSE) );
+  Clear_Mode( PASS_PRED );
+  return( FALSE );
 }
 
 
-gboolean
-on_multi_loc_delete_event(
+  gboolean
+on_multi_location_delete_event(
 	GtkWidget       *widget,
 	GdkEvent        *event,
 	gpointer         user_data)
 {
   Set_Mode( END_MULTI_LOC );
-  return FALSE;
+  return( FALSE );
 }
 
 
-gboolean
-on_illum_pred_delete_event(
+  gboolean
+on_illum_predict_delete_event(
 	GtkWidget       *widget,
 	GdkEvent        *event,
 	gpointer         user_data)
 {
-  Set_Mode( END_ILLUM_PRED );
-  return FALSE;
+  while( g_main_context_iteration(NULL, FALSE) );
+  Clear_Mode( ILLUM_PRED );
+  return( FALSE );
 }
 
 
-void
+  void
 on_error_quit_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
@@ -350,10 +370,10 @@ on_error_quit_clicked(
 }
 
 
-void
-  on_error_ok_clicked
-(GtkButton       *button,
- gpointer         user_data)
+  void
+on_error_ok_clicked(
+	GtkButton       *button,
+	gpointer         user_data)
 {
   gtk_widget_destroy( error_dialog );
 }
@@ -377,7 +397,7 @@ tree_selection_changed_cb(
   }
 }
 
-void
+  void
 on_access_pred_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
@@ -386,7 +406,7 @@ on_access_pred_clicked(
 }
 
 
-void
+  void
 on_visible_pred_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
@@ -396,7 +416,7 @@ on_visible_pred_clicked(
 }
 
 
-void
+  void
 on_fwd_pred_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
@@ -405,7 +425,7 @@ on_fwd_pred_clicked(
 }
 
 
-void
+  void
 on_pass_redo_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
@@ -414,43 +434,43 @@ on_pass_redo_clicked(
 }
 
 
-void
+  void
 on_loc_up_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
 {
-  gbl_change_sat_loc = BACK_OBSERVER;
+  change_sat_loc = BACK_OBSERVER;
 }
 
 
-void
+  void
 on_loc_dn_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
 {
-  gbl_change_sat_loc = FORWD_OBSERVER;
+  change_sat_loc = FORWD_OBSERVER;
 }
 
 
-void
+  void
 on_loc_frst_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
 {
-  gbl_change_sat_loc = FIRST_OBSERVER;
+  change_sat_loc = FIRST_OBSERVER;
 }
 
 
-void
+  void
 on_loc_last_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
 {
-  gbl_change_sat_loc = LAST_OBSERVER;
+  change_sat_loc = LAST_OBSERVER;
 }
 
 
-void
+  void
 on_ill_fwd_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
@@ -459,7 +479,7 @@ on_ill_fwd_clicked(
 }
 
 
-void
+  void
 on_ill_back_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
@@ -468,7 +488,7 @@ on_ill_back_clicked(
 }
 
 
-void
+  void
 on_ill_redo_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
@@ -477,151 +497,151 @@ on_ill_redo_clicked(
 }
 
 
-void
+  void
 on_sat_up_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
 {
-  gbl_change_sat_loc = BACK_SATELLITE;
+  change_sat_loc = BACK_SATELLITE;
 }
 
 
-void
+  void
 on_sat_dn_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
 {
-  gbl_change_sat_loc = FORWD_SATELLITE;
+  change_sat_loc = FORWD_SATELLITE;
 }
 
 
-void
+  void
 on_sat_frst_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
 {
-  gbl_change_sat_loc = FIRST_SATELLITE;
+  change_sat_loc = FIRST_SATELLITE;
 }
 
 
-void
+  void
 on_sat_last_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
 {
-  gbl_change_sat_loc = LAST_SATELLITE;
+  change_sat_loc = LAST_SATELLITE;
 }
 
-gboolean
+  gboolean
 on_calibration_delete_event(
 	GtkWidget       *widget,
 	GdkEvent        *event,
 	gpointer         user_data)
 {
   /* Prevent calibration window closure */
-  return TRUE;
+  return( TRUE );
 }
 
 
-void
+  void
 on_offset_calibration_activate(
 	GtkMenuItem     *menuitem,
 	gpointer         user_data)
 {
   Clear_Mode( ALL_MODES );
-  gtk_idle_add( Show_Offset_Calibration, NULL );
+  g_idle_add( Show_Offset_Calibration, NULL );
 }
 
 
-void
+  void
 on_fullscale_calibration_activate(
 	GtkMenuItem     *menuitem,
 	gpointer         user_data)
 {
   Clear_Mode( ALL_MODES );
-  gtk_idle_add( Show_Fullscale_Calibration, NULL );
+  g_idle_add( Show_Fullscale_Calibration, NULL );
 }
 
 
-void
+  void
 on_track_moon_activate(
 	GtkMenuItem     *menuitem,
 	gpointer         user_data)
 {
   ClearFlag( TRACKING_FLAGS );
   SetFlag( TRACK_MOON );
-  gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON
-	  (lookup_widget(sat_track, "rotor_control")), TRUE );
+  gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(
+		Builder_Get_Object(satellite_track_builder, "rotor_control")), TRUE );
 }
 
 
-void
+  void
 on_track_sun_activate(
 	GtkMenuItem     *menuitem,
 	gpointer         user_data)
 {
   ClearFlag( TRACKING_FLAGS );
   SetFlag( TRACK_SUN );
-  gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON
-	  (lookup_widget(sat_track, "rotor_control")), TRUE );
+  gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(
+		Builder_Get_Object(satellite_track_builder, "rotor_control")), TRUE );
 }
 
 
-void
+  void
 on_track_polar_star_activate(
 	GtkMenuItem     *menuitem,
 	gpointer         user_data)
 {
   ClearFlag( TRACKING_FLAGS );
   SetFlag( TRACK_POLAR );
-  gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON
-	  (lookup_widget(sat_track, "rotor_control")), TRUE );
+  gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(
+		Builder_Get_Object(satellite_track_builder, "rotor_control")), TRUE );
 }
 
 
-void
+  void
 on_park_rotors_activate(
 	GtkMenuItem     *menuitem,
 	gpointer         user_data)
 {
   ClearFlag( TRACKING_FLAGS );
   SetFlag( PARK_ROTORS );
-  gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON
-	  (lookup_widget(sat_track, "rotor_control")), TRUE );
+  gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(
+		Builder_Get_Object(satellite_track_builder, "rotor_control")), TRUE );
 }
 
 
-void
+  void
 on_position_rotors_activate(
 	GtkMenuItem     *menuitem,
 	gpointer         user_data)
 {
-  azel_dialog = create_azel_dialog();
+  azel_dialog = create_azel_dialog( &azel_builder );
   gtk_widget_show( azel_dialog );
 }
 
 
-void
+  void
 on_quit_activate(
 	GtkMenuItem     *menuitem,
 	gpointer         user_data)
 {
-  gtk_widget_destroy( sat_track );
+  gtk_widget_destroy( satellite_track );
 }
 
 
-void
+  void
 on_new_location_activate(
 	GtkMenuItem     *menuitem,
 	gpointer         user_data)
 {
-  loc_dialog = create_loc_dialog();
+  loc_dialog = create_loc_dialog( &loc_builder );
   gtk_widget_show( loc_dialog );
 }
 
 
-gboolean
-on_sat_track_button_press_event(
+  gboolean
+on_satellite_track_button_press_event(
 	GtkWidget       *widget,
 	GdkEventButton  *event,
 	gpointer         user_data)
@@ -633,19 +653,18 @@ on_sat_track_button_press_event(
 	/* Initialize on first call */
 	if( first_call )
 	{
-	  main_menu = create_main_menu();
+	  popup_menu = create_popup_menu( &popup_builder );
 	  first_call = FALSE;
 	}
 
-	gtk_menu_popup( GTK_MENU(main_menu),
-		NULL, NULL, NULL, NULL, 3, 0);
+	gtk_menu_popup_at_pointer( GTK_MENU(popup_menu), NULL );
   }
 
-  return TRUE;
+  return( TRUE );
 }
 
 
-void
+  void
 on_azel_apply_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
@@ -655,27 +674,23 @@ on_azel_apply_clicked(
   ClearFlag( TRACKING_FLAGS );
   SetFlag( TRACK_MANUAL );
 
-  entry = GTK_ENTRY( lookup_widget(azel_dialog, "az_entry") );
-  gbl_azim = Atof( gtk_entry_get_text(entry) );
-  entry = GTK_ENTRY( lookup_widget(azel_dialog, "el_entry") );
-  gbl_elev = Atof( gtk_entry_get_text(entry) );
+  entry = GTK_ENTRY( Builder_Get_Object(azel_builder, "az_entry") );
+  azimuth = Atof( gtk_entry_get_text(entry) );
+  entry = GTK_ENTRY( Builder_Get_Object(azel_builder, "el_entry") );
+  elevation = Atof( gtk_entry_get_text(entry) );
 
   /* Set limits to values */
-  if( gbl_azim > 360. )
-	gbl_azim = 360.;
-  if( gbl_azim < 0. )
-	gbl_azim = 0.;
-  if( gbl_elev > 180. )
-	gbl_azim = 180.;
-  if( gbl_azim < 0. )
-	gbl_azim = 0.;
+  if( azimuth > 360.0 )	azimuth = 360.;
+  if( azimuth < 0.0 ) azimuth = 0.0;
+  if( elevation > 180.0 ) elevation = 180.0;
+  if( elevation < 0.0 ) elevation = 0.0;
 
-  gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON
-	  (lookup_widget(sat_track, "rotor_control")), TRUE );
+  gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(
+		Builder_Get_Object(satellite_track_builder, "rotor_control")), TRUE );
 }
 
 
-void
+  void
 on_azel_ok_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
@@ -684,7 +699,7 @@ on_azel_ok_clicked(
   gtk_widget_destroy( azel_dialog );
 }
 
-void
+  void
 on_loc_apply_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
@@ -696,92 +711,92 @@ on_loc_apply_clicked(
   double lon, lat;
 
 
-  /* Reallocate memory to obs data */
-  mem_realloc( (void **)&gbl_obs_data,
-		sizeof(observer_status_t) * (size_t)(gbl_num_obs + 1),
-		_("for gbl_obs_data in on_loc_apply_clicked()") );
-  if( gbl_obs_data == NULL ) return;
+  /* Reallocate memory to observer data */
+  mem_realloc( (void **)&observer_data,
+	  sizeof(observer_status_t) * (size_t)(num_obs + 1),
+	  _("for observer_data in on_loc_apply_clicked()") );
+  if( observer_data == NULL ) return;
 
   /* Clear entry flags */
   ClearFlag( LOC_ENTERED | POSITION_ENTERED );
 
   /* Enter location name and remove trailing spaces */
-  entry = GTK_ENTRY( lookup_widget(loc_dialog, "loc_name") );
-  Strlcpy( gbl_obs_data[gbl_num_obs].loc_name,
+  entry = GTK_ENTRY( Builder_Get_Object(loc_builder, "loc_name") );
+  Strlcpy( observer_data[num_obs].loc_name,
 	  gtk_entry_get_text(entry),
-	  sizeof(gbl_obs_data[gbl_num_obs].loc_name) );
+	  sizeof(observer_data[num_obs].loc_name) );
 
   /* Dump trailing spaces from location name */
-  idx = (int)strlen( gbl_obs_data[gbl_num_obs].loc_name );
-  while( (gbl_obs_data[gbl_num_obs].loc_name[--idx] == ' ') && (idx != 0) );
-  gbl_obs_data[gbl_num_obs].loc_name[++idx] = '\0';
+  idx = (int)strlen( observer_data[num_obs].loc_name );
+  while( (observer_data[num_obs].loc_name[--idx] == ' ') && (idx != 0) );
+  observer_data[num_obs].loc_name[++idx] = '\0';
 
   /* Enter QTH locator */
-  entry = GTK_ENTRY( lookup_widget(loc_dialog, "qth_loc") );
-  Strlcpy( gbl_obs_data[gbl_num_obs].grid_loc,
+  entry = GTK_ENTRY( Builder_Get_Object(loc_builder, "qth_loc") );
+  Strlcpy( observer_data[num_obs].grid_loc,
 	  gtk_entry_get_text(entry),
-	  sizeof(gbl_obs_data[gbl_num_obs].grid_loc) );
+	  sizeof(observer_data[num_obs].grid_loc) );
 
   /* Set QTH locator flag if entered */
-  if( strlen(gbl_obs_data[gbl_num_obs].grid_loc) != 0 )
+  if( strlen(observer_data[num_obs].grid_loc) != 0 )
   {
 	SetFlag( LOC_ENTERED );
 
 	/* Display formatted locator if valid */
-	if( Locator_Valid(gbl_obs_data[gbl_num_obs].grid_loc) )
-	  gtk_entry_set_text( entry, gbl_obs_data[gbl_num_obs].grid_loc );
+	if( Locator_Valid(observer_data[num_obs].grid_loc) )
+	  gtk_entry_set_text( entry, observer_data[num_obs].grid_loc );
 	else
 	  gtk_entry_set_text( entry, _("ERROR") );
   }
 
   /* Enter longitude deg */
-  entry = GTK_ENTRY( lookup_widget(loc_dialog, "lon_deg") );
+  entry = GTK_ENTRY( Builder_Get_Object(loc_builder, "lon_deg") );
   Strlcpy( temp, gtk_entry_get_text(entry), s );
   if( strlen(temp) != 0 )
   {
 	SetFlag(POSITION_ENTERED);
-	gbl_obs_data[gbl_num_obs].obs_geodetic.lon = Atof(temp);
+	observer_data[num_obs].obs_geodetic.lon = Atof(temp);
   }
 
   /* Enter longitude min */
-  entry = GTK_ENTRY( lookup_widget(loc_dialog, "lon_min") );
+  entry = GTK_ENTRY( Builder_Get_Object(loc_builder, "lon_min") );
   Strlcpy( temp, gtk_entry_get_text(entry), s );
-  if( gbl_obs_data[gbl_num_obs].obs_geodetic.lon < 0. )
-	gbl_obs_data[gbl_num_obs].obs_geodetic.lon -= Atof(temp)/60.;
+  if( observer_data[num_obs].obs_geodetic.lon < 0. )
+	observer_data[num_obs].obs_geodetic.lon -= Atof(temp)/60.;
   else
-	gbl_obs_data[gbl_num_obs].obs_geodetic.lon += Atof(temp)/60.;
+	observer_data[num_obs].obs_geodetic.lon += Atof(temp)/60.;
 
   /* Limit longitude to +-180 deg */
-  if( gbl_obs_data[gbl_num_obs].obs_geodetic.lon >  180. ||
-	  gbl_obs_data[gbl_num_obs].obs_geodetic.lon < -180. )
+  if( observer_data[num_obs].obs_geodetic.lon >  180. ||
+	  observer_data[num_obs].obs_geodetic.lon < -180. )
   {
-	gtk_entry_set_text( GTK_ENTRY(lookup_widget(loc_dialog, "lon_deg") ),
+	gtk_entry_set_text( GTK_ENTRY(Builder_Get_Object(loc_builder, "lon_deg") ),
 		_("ERROR") );
 	return;
   }
 
   /* Enter latitude deg */
-  entry = GTK_ENTRY( lookup_widget(loc_dialog, "lat_deg") );
+  entry = GTK_ENTRY( Builder_Get_Object(loc_builder, "lat_deg") );
   Strlcpy( temp, gtk_entry_get_text(entry), s );
   if( strlen(temp) != 0 )
   {
 	SetFlag(POSITION_ENTERED);
-	gbl_obs_data[gbl_num_obs].obs_geodetic.lat = Atof(temp);
+	observer_data[num_obs].obs_geodetic.lat = Atof(temp);
   }
 
   /* Enter latitude min */
-  entry = GTK_ENTRY( lookup_widget(loc_dialog, "lat_min") );
+  entry = GTK_ENTRY( Builder_Get_Object(loc_builder, "lat_min") );
   Strlcpy( temp, gtk_entry_get_text(entry), s );
-  if( gbl_obs_data[gbl_num_obs].obs_geodetic.lat < 0. )
-	gbl_obs_data[gbl_num_obs].obs_geodetic.lat -= Atof(temp)/60.;
+  if( observer_data[num_obs].obs_geodetic.lat < 0. )
+	observer_data[num_obs].obs_geodetic.lat -= Atof(temp)/60.;
   else
-	gbl_obs_data[gbl_num_obs].obs_geodetic.lat += Atof(temp)/60.;
+	observer_data[num_obs].obs_geodetic.lat += Atof(temp)/60.;
 
   /* Limit latitude to +-90 deg */
-  if( gbl_obs_data[gbl_num_obs].obs_geodetic.lat >  90. ||
-	  gbl_obs_data[gbl_num_obs].obs_geodetic.lat < -90. )
+  if( observer_data[num_obs].obs_geodetic.lat >  90. ||
+	  observer_data[num_obs].obs_geodetic.lat < -90. )
   {
-	gtk_entry_set_text( GTK_ENTRY(lookup_widget(loc_dialog, "lat_deg")),
+	gtk_entry_set_text( GTK_ENTRY(Builder_Get_Object(loc_builder, "lat_deg")),
 		_("ERROR") );
 	return;
   }
@@ -792,18 +807,18 @@ on_loc_apply_clicked(
 	  isFlagSet(POSITION_ENTERED) )
   {
 	/* Check grid locator against position */
-	lon = gbl_obs_data[gbl_num_obs].obs_geodetic.lon;
+	lon = observer_data[num_obs].obs_geodetic.lon;
 	if( lon > 180. )
 	  lon -= 360.;
-	lat = gbl_obs_data[gbl_num_obs].obs_geodetic.lat;
-	Strlcpy( gloc, gbl_obs_data[gbl_num_obs].grid_loc, sizeof(gloc) );
+	lat = observer_data[num_obs].obs_geodetic.lat;
+	Strlcpy( gloc, observer_data[num_obs].grid_loc, sizeof(gloc) );
 
 	Position_to_Grid_Locator( lon, lat, gloc);
 
-	if( strcmp(gbl_obs_data[gbl_num_obs].grid_loc, gloc) != 0 )
+	if( strcmp(observer_data[num_obs].grid_loc, gloc) != 0 )
 	{
 	  gtk_entry_set_text( GTK_ENTRY(
-			lookup_widget(loc_dialog, "loc_name")),
+			Builder_Get_Object(loc_builder, "loc_name")),
 		  _("Locator/Position Mismatch") );
 	  return;
 	}
@@ -812,44 +827,45 @@ on_loc_apply_clicked(
   else if( isFlagSet(LOC_ENTERED) &&
 	  isFlagClear(POSITION_ENTERED) )
   {
-	Grid_Locator_to_Position(gbl_obs_data[gbl_num_obs].grid_loc,
+	Grid_Locator_to_Position(observer_data[num_obs].grid_loc,
 		&lon, &lat);
 
-	gbl_obs_data[gbl_num_obs].obs_geodetic.lon = lon;
-	gbl_obs_data[gbl_num_obs].obs_geodetic.lat = lat;
+	observer_data[num_obs].obs_geodetic.lon = lon;
+	observer_data[num_obs].obs_geodetic.lat = lat;
   }
   /* If only Position is specified, calculate Grid Locator */
   else if( isFlagSet(POSITION_ENTERED) &&
 	  isFlagClear(LOC_ENTERED) )
   {
-	lon = gbl_obs_data[gbl_num_obs].obs_geodetic.lon;
+	lon = observer_data[num_obs].obs_geodetic.lon;
 	if( lon > 180. ) lon -= 360.;
-	lat = gbl_obs_data[gbl_num_obs].obs_geodetic.lat;
-	Position_to_Grid_Locator(lon, lat, gbl_obs_data[gbl_num_obs].grid_loc);
+	lat = observer_data[num_obs].obs_geodetic.lat;
+	Position_to_Grid_Locator(lon, lat, observer_data[num_obs].grid_loc);
   }
   else
   {
-	gtk_entry_set_text( GTK_ENTRY(lookup_widget(loc_dialog, "loc_name")),
+	gtk_entry_set_text( GTK_ENTRY(
+		  Builder_Get_Object(loc_builder, "loc_name")),
 		_("No Valid Entries") );
 	return;
   }
 
   /* Copy height */
-  entry = GTK_ENTRY( lookup_widget(loc_dialog, "loc_height") );
-  gbl_obs_data[gbl_num_obs].obs_geodetic.hgt =
+  entry = GTK_ENTRY( Builder_Get_Object(loc_builder, "loc_height") );
+  observer_data[num_obs].obs_geodetic.hgt =
 	Atof( gtk_entry_get_text(entry) ) / 1000.0;
 
   /* Convert to rads */
-  gbl_obs_data[gbl_num_obs].obs_geodetic.lat =
-	Radians( gbl_obs_data[gbl_num_obs].obs_geodetic.lat );
-  gbl_obs_data[gbl_num_obs].obs_geodetic.lon =
-	Radians( gbl_obs_data[gbl_num_obs].obs_geodetic.lon );
+  observer_data[num_obs].obs_geodetic.lat =
+	Radians( observer_data[num_obs].obs_geodetic.lat );
+  observer_data[num_obs].obs_geodetic.lon =
+	Radians( observer_data[num_obs].obs_geodetic.lon );
 
-  gbl_num_obs++;
+  num_obs++;
 }
 
 
-void
+  void
 on_loc_close_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
@@ -858,12 +874,12 @@ on_loc_close_clicked(
 }
 
 
-void
+  void
 on_loc_save_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
 {
-  Save_Location( &gbl_obs_data[gbl_num_obs - 1] );
+  Save_Location( &observer_data[num_obs - 1] );
 }
 
 
@@ -878,37 +894,37 @@ on_mode_chng_button_press_event(
 	switch( event->button )
 	{
 	  case 1:
-		if( ++gbl_mode_idx >= gbl_num_modes )
-		  gbl_mode_idx = 0;
+		if( ++mode_index >= num_modes )
+		  mode_index = 0;
 		break;
 
 	  case 2:
 		break;
 
 	  case 3:
-		if( --gbl_mode_idx < 0 )
-		  gbl_mode_idx += gbl_num_modes;
+		if( --mode_index < 0 )
+		  mode_index += num_modes;
 		break;
 	}
 
-	Initialize_Tcvr( gbl_mode_idx );
+	Initialize_Tcvr( mode_index );
   }
 
-  return TRUE;
+  return( TRUE );
 }
 
 
-gboolean
+  gboolean
 on_error_dialog_delete_event(
 	GtkWidget       *widget,
 	GdkEvent        *event,
 	gpointer         user_data)
 {
-  return TRUE;
+  return( TRUE );
 }
 
 
-void
+  void
 on_freeze_multisat_clicked(
 	GtkButton       *button,
 	gpointer         user_data)
@@ -922,13 +938,85 @@ on_freeze_multisat_clicked(
 
   void
 on_error_dialog_destroy(
-	GtkObject       *object,
-	gpointer         user_data)
+	GObject       *object,
+	gpointer       user_data)
 {
   error_dialog = NULL;
 }
 
 
+  void
+on_azel_dialog_destroy(
+	GObject       *object,
+	gpointer       user_data)
+{
+  azel_dialog = NULL;
+}
+
+
+  void
+on_calibration_destroy(
+	GObject       *object,
+	gpointer       user_data)
+{
+  calibrate = NULL;
+}
+
+
+  void
+on_illum_predict_destroy(
+	GObject       *object,
+	gpointer       user_data)
+{
+  illum_predict = NULL;
+}
+
+
+  void
+on_loc_dialog_destroy(
+	GObject       *object,
+	gpointer       user_data)
+{
+  loc_dialog = NULL;
+}
+
+
+  void
+on_multi_location_destroy(
+	GObject       *object,
+	gpointer       user_data)
+{
+  multi_location = NULL;
+}
+
+
+  void
+on_multi_satellite_destroy(
+	GObject       *object,
+	gpointer       user_data)
+{
+  multi_satellite = NULL;
+}
+
+
+  void
+on_pass_predict_destroy(
+	GObject       *object,
+	gpointer       user_data)
+{
+  pass_predict = NULL;
+}
+
+
+  void
+on_popup_menu_destroy(
+	GObject       *object,
+	gpointer       user_data)
+{
+  popup_menu = NULL;
+}
+
+
   void
 on_start_togglebutton_toggled(
 	GtkToggleButton *togglebutton,
@@ -937,11 +1025,15 @@ on_start_togglebutton_toggled(
   static guint s;
   if( gtk_toggle_button_get_active(togglebutton) )
   {
-	Set_Mode( SINGLE_SAT );
+	Set_Mode( SINGLE_SAT | XSATCOM_RUN );
 	Central_Mode( NULL );
 	s = g_timeout_add_seconds( 1, Central_Mode, "" );
   }
-  else g_source_remove( s );
+  else
+  {
+	ClearFlag( XSATCOM_RUN );
+	g_source_remove( s );
+  }
 }
 
 
@@ -960,18 +1052,49 @@ on_download_tle_activate(
   if( strcmp(ret_str, "OK!") != 0 )
 	Error_Dialog( ret_str, FATAL );
   else
-	gbl_change_sat_loc = DNLD_TLE_SETS;
+	change_sat_loc = DNLD_TLE_SETS;
 }
 
 
   gboolean
-on_illum_drawingarea_expose_event(
-	GtkWidget       *widget,
-	GdkEventExpose  *event,
-	gpointer         user_data)
+on_illum_drawingarea_draw(
+	GtkWidget *widget,
+	cairo_t   *cr,
+	gpointer   user_data)
 {
-  Clear_Mode( ILLUM_PRED_DONE );
-  return TRUE;
+  if( isModeSet(ILLUM_PRED) && isModeSet(XSATCOM_RUN) )
+	Draw_Illum_Predict( cr );
+  return( FALSE );
+}
+
+
+  void
+on_illum_drawingarea_destroy(
+	GObject       *object,
+	gpointer       user_data)
+{
+  illum_drawingarea = NULL;
+}
+
+
+  gboolean
+on_pass_drawingarea_draw(
+	GtkWidget *widget,
+	cairo_t   *cr,
+	gpointer   user_data)
+{
+  if( isModeSet(PASS_PRED) && isModeSet(XSATCOM_RUN) )
+	Pass_Predict_Mode( cr );
+  return( FALSE );
+}
+
+
+  void
+on_pass_drawingarea_destroy(
+	GObject       *object,
+	gpointer       user_data)
+{
+  pass_drawingarea = NULL;
 }
 
 
@@ -982,12 +1105,12 @@ on_dnlink_freq_scroll_event(
 	gpointer         user_data)
 {
   if( event->scroll.direction == GDK_SCROLL_UP )
-	gbl_tcvr_status.dnlink_freq += 1000;
+	transceiver_status.dnlink_freq += 10;
   else if( event->scroll.direction == GDK_SCROLL_DOWN )
-	gbl_tcvr_status.dnlink_freq -= 1000;
+	transceiver_status.dnlink_freq -= 10;
   SetFlag( NEW_DNLINK_FREQ );
 
-  Show_CAT_Control( &gbl_tcvr_status );
+  Show_CAT_Control( &transceiver_status );
   return( TRUE );
 }
 
@@ -999,12 +1122,12 @@ on_uplink_freq_scroll_event(
 	gpointer         user_data)
 {
   if( event->scroll.direction == GDK_SCROLL_UP )
-	gbl_tcvr_status.uplink_freq += 1000;
+	transceiver_status.uplink_freq += 10;
   else if( event->scroll.direction == GDK_SCROLL_DOWN )
-	gbl_tcvr_status.uplink_freq -= 1000;
+	transceiver_status.uplink_freq -= 10;
   SetFlag( NEW_UPLINK_FREQ );
 
-  Show_CAT_Control( &gbl_tcvr_status );
+  Show_CAT_Control( &transceiver_status );
   return( TRUE );
 }
 
