@@ -1,15 +1,4 @@
-/*  common.h
- *
- *  Common header file for xsatcom: An interface application
- *  for Yaesu's GS-232 Az-El antenna rotor controller
- */
-
 /*
- *  xsatcom: A X/GTK+ application to track satellites using the
- *  NORAD SGP4/SDP4 orbit calculation routines. The moon and sun
- *  are also tracked.
- *
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 2 of
@@ -27,13 +16,15 @@
 #ifndef COMMON_H
 #define COMMON_H	1
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <gtk/gtk.h>
-#include <gdk/gdkkeysyms.h>
 #include <signal.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <fcntl.h>
-#include <errno.h>
 #include <sys/ioctl.h>
 #include <stdio.h>
 #include <termios.h>
@@ -91,6 +82,18 @@ enum
 
 /*-------------------------------------------------------------------*/
 
+/* Definitions for selecting active windows */
+enum
+{
+  SATELLITE_TRACK = 1,
+  MULTI_SATELLITE,
+  PASS_PREDICT,
+  MULTI_LOCATION,
+  ILLUM_PREDICT
+};
+
+/*-------------------------------------------------------------------*/
+
 /* Special characters */
 #define LF      0x0A /* Line Feed */
 #define CR      0x0D /* Carriage Return */
@@ -108,15 +111,14 @@ enum
 #define END_SINGLE_SAT      0x00000020
 #define END_MULTI_SAT       0x00000040
 #define END_MULTI_LOC       0x00000080
-#define END_PASS_PRED       0x00000100
-#define END_ILLUM_PRED      0x00000200
-#define PASS_PRED_FWD       0x00000400
-#define PASS_PRED_RESET     0x00000800
-#define PASS_PRED_ACCESS    0x00001000
-#define ILLUM_PRED_FWD      0x00002000
-#define ILLUM_PRED_BACK     0x00004000
-#define ILLUM_PRED_REDO     0x00008000
-#define ILLUM_PRED_DONE     0x00010000
+#define PASS_PRED_FWD       0x00000100
+#define PASS_PRED_RESET     0x00000200
+#define PASS_PRED_ACCESS    0x00000400
+#define ILLUM_PRED_FWD      0x00000800
+#define ILLUM_PRED_BACK     0x00001000
+#define ILLUM_PRED_REDO     0x00002000
+#define ILLUM_PRED_DONE     0x00004000
+#define XSATCOM_RUN		    0x00008000
 #define ALL_MODES           -1
 
 /* GC colors */
@@ -190,7 +192,7 @@ enum
 
 /* Flags for controlling xplanet satellite plots */
 #define XPLANET_PLOT      0x00800000
-#define MULTISAT_PLOT     0x0100000
+#define MULTISAT_PLOT     0x01000000
 #define ALL_FLAGS        ~0
 
 #define XPLANET_STOPPED		0
@@ -344,7 +346,7 @@ typedef struct
 	name[NAME_SIZE], /* Satellite name string    */
 	idesg[9];		 /* International Designator */
 
-} elem_set_t;
+} element_set_t;
 
 /* Common arguments between deep-space functions */
 typedef struct
@@ -363,7 +365,7 @@ typedef struct
 
 } deep_arg_t;
 
-/* Data from satellite pass predicitons */
+/* Data from satellite pass predictions */
 typedef struct
 {
   int flags;
@@ -484,7 +486,7 @@ typedef struct
 
   int flags;	 /* Indicates what transponder data is given */
 
-} tcvr_status_t;
+} transceiver_status_t;
 
 /* Runtime config data */
 typedef struct
@@ -515,6 +517,8 @@ typedef struct
   /* WGF data for str6/sgp4 */
   double tumin, radiusearthkm, xke, j2, j3, j4, j3oj2;
 
+  char xsatcom_glade[128];
+
 } rc_data_t;
 
 /* Transceiver type */
@@ -527,13 +531,38 @@ enum
   K3
 };
 
+
+/*
+ * Standard gettext macros.
+ */
+#ifdef ENABLE_NLS
+#  include <libintl.h>
+#  undef _
+#  define _(String) dgettext (PACKAGE, String)
+#  define Q_(String) g_strip_context ((String), gettext (String))
+#  ifdef gettext_noop
+#    define N_(String) gettext_noop (String)
+#  else
+#    define N_(String) (String)
+#  endif
+#else
+#  define textdomain(String) (String)
+#  define gettext(String) (String)
+#  define dgettext(Domain,Message) (Message)
+#  define dcgettext(Domain,Message,Type) (Message)
+#  define bindtextdomain(Domain,Directory) (Domain)
+#  define _(String) (String)
+#  define Q_(String) g_strip_context ((String), (String))
+#  define N_(String) (String)
+#endif
+
 /*-------------------------------------------------------------------*/
 
 /* Function Prototypes produced by cproto */
 /* callbacks.c */
-void Error_Dialog(char *message, gboolean fatal);
-void on_sat_track_destroy(GtkObject *object, gpointer user_data);
-gboolean on_sat_track_delete_event(GtkWidget *widget, GdkEvent *event, gpointer user_data);
+void Error_Dialog(char *mesg, gboolean fatal);
+void on_satellite_track_destroy(GObject *object, gpointer user_data);
+gboolean on_satellite_track_delete_event(GtkWidget *widget, GdkEvent *event, gpointer user_data);
 void on_txrx_track_toggled(GtkToggleButton *togglebutton, gpointer user_data);
 void on_update_track_clicked(GtkButton *button, gpointer user_data);
 void on_doppler_corr_toggled(GtkToggleButton *togglebutton, gpointer user_data);
@@ -545,11 +574,12 @@ void on_multi_loc_clicked(GtkButton *button, gpointer user_data);
 void on_illum_pred_clicked(GtkButton *button, gpointer user_data);
 void on_xplanet_plot_toggled(GtkToggleButton *togglebutton, gpointer user_data);
 void on_multisat_plot_toggled(GtkToggleButton *togglebutton, gpointer user_data);
-gboolean on_multi_sat_delete_event(GtkWidget *widget, GdkEvent *event, gpointer user_data);
-gboolean on_pass_pred_delete_event(GtkWidget *widget, GdkEvent *event, gpointer user_data);
-gboolean on_multi_loc_delete_event(GtkWidget *widget, GdkEvent *event, gpointer user_data);
-gboolean on_illum_pred_delete_event(GtkWidget *widget, GdkEvent *event, gpointer user_data);
+gboolean on_multi_satellite_delete_event(GtkWidget *widget, GdkEvent *event, gpointer user_data);
+gboolean on_pass_predict_delete_event(GtkWidget *widget, GdkEvent *event, gpointer user_data);
+gboolean on_multi_location_delete_event(GtkWidget *widget, GdkEvent *event, gpointer user_data);
+gboolean on_illum_predict_delete_event(GtkWidget *widget, GdkEvent *event, gpointer user_data);
 void on_error_quit_clicked(GtkButton *button, gpointer user_data);
+void on_error_ok_clicked(GtkButton *button, gpointer user_data);
 void tree_selection_changed_cb(GtkTreeSelection *selection, gpointer user_data);
 void on_access_pred_clicked(GtkButton *button, gpointer user_data);
 void on_visible_pred_clicked(GtkButton *button, gpointer user_data);
@@ -576,7 +606,7 @@ void on_park_rotors_activate(GtkMenuItem *menuitem, gpointer user_data);
 void on_position_rotors_activate(GtkMenuItem *menuitem, gpointer user_data);
 void on_quit_activate(GtkMenuItem *menuitem, gpointer user_data);
 void on_new_location_activate(GtkMenuItem *menuitem, gpointer user_data);
-gboolean on_sat_track_button_press_event(GtkWidget *widget, GdkEventButton *event, gpointer user_data);
+gboolean on_satellite_track_button_press_event(GtkWidget *widget, GdkEventButton *event, gpointer user_data);
 void on_azel_apply_clicked(GtkButton *button, gpointer user_data);
 void on_azel_ok_clicked(GtkButton *button, gpointer user_data);
 void on_loc_apply_clicked(GtkButton *button, gpointer user_data);
@@ -585,144 +615,106 @@ void on_loc_save_clicked(GtkButton *button, gpointer user_data);
 gboolean on_mode_chng_button_press_event(GtkWidget *widget, GdkEventButton *event, gpointer user_data);
 gboolean on_error_dialog_delete_event(GtkWidget *widget, GdkEvent *event, gpointer user_data);
 void on_freeze_multisat_clicked(GtkButton *button, gpointer user_data);
-void on_error_dialog_destroy(GtkObject *object, gpointer user_data);
+void on_error_dialog_destroy(GObject *object, gpointer user_data);
+void on_azel_dialog_destroy(GObject *object, gpointer user_data);
+void on__dialog_destroy(GObject *object, gpointer user_data);
+void on_calibration_destroy(GObject *object, gpointer user_data);
+void on_illum_predict_destroy(GObject *object, gpointer user_data);
+void on_loc_dialog_destroy(GObject *object, gpointer user_data);
+void on_multi_location_destroy(GObject *object, gpointer user_data);
+void on_multi_satellite_destroy(GObject *object, gpointer user_data);
+void on_pass_predict_destroy(GObject *object, gpointer user_data);
+void on_popup_menu_destroy(GObject *object, gpointer user_data);
 void on_start_togglebutton_toggled(GtkToggleButton *togglebutton, gpointer user_data);
 void on_download_tle_activate(GtkMenuItem *menuitem, gpointer user_data);
-gboolean on_illum_drawingarea_expose_event(GtkWidget *widget, GdkEventExpose *event, gpointer user_data);
+gboolean on_illum_drawingarea_draw(GtkWidget *widget, cairo_t *cr, gpointer user_data);
+void on_illum_drawingarea_destroy(GObject *object, gpointer user_data);
+gboolean on_pass_drawingarea_draw(GtkWidget *widget, cairo_t *cr, gpointer user_data);
+void on_pass_drawingarea_destroy(GObject *object, gpointer user_data);
+gboolean on_dnlink_freq_scroll_event(GtkWidget *widget, GdkEvent *event, gpointer user_data);
+gboolean on_uplink_freq_scroll_event(GtkWidget *widget, GdkEvent *event, gpointer user_data);
 /* cat.c */
 gboolean Open_Tcvr_Serial(void);
 void Close_Tcvr_Serial(void);
-void Cancel_CAT(void);
-gboolean Read_Tcvr_Serial(char *data, size_t len);
-gboolean Write_Tcvr_Serial(char *data, size_t len);
-gboolean Tcvr_Status(int action, tcvr_status_t *tcvr_status);
-gboolean K3_Get_Data(char *get, char *data);
-gboolean K3_SubRx_Status(int action, tcvr_status_t *tcvr_status);
-gboolean K3_Set_Freq_Mode(int action, tcvr_status_t *tcvr_status);
-gboolean K3_Original_Status(int action);
-gboolean K3_Tcvr_Status(int action, tcvr_status_t *tcvr_status);
-gboolean FT8x7_Set_Freq_Mode(int action, tcvr_status_t *tcvr_status);
-gboolean FT8x7_Get_Freq_Mode(int action, tcvr_status_t *tcvr_status);
-gboolean FT8x7_Set_CTCSS(tcvr_status_t *tcvr_status);
-gboolean FT8x7_Tcvr_Status(int action, tcvr_status_t *tcvr_status);
 gboolean Initialize_Tcvr(int mode_idx);
 void CAT_Control(satellite_status_t *sat_status);
 /* date_time.c */
-double Julian_Date_of_Epoch(double epoch);
-double Epoch_Time(double jd);
-int DOY(int yr, int mo, int dy);
-double Fraction_of_Day(int hr, int mi, int se);
-void Calendar_Date(double jd, struct tm *cdate);
-void Time_of_Day(double jd, struct tm *cdate);
 double Julian_Date(struct tm *cdate);
 void Date_Time(double julian_date, struct tm *cdate);
-int Check_Date(struct tm *cdate);
-struct tm Time_to_UTC(struct tm *cdate);
-struct tm Time_from_UTC(struct tm *cdate);
-double JD_to_UTC(double jt);
-double JD_from_UTC(double jt);
-double Delta_ET(double year);
-double Julian_Date_of_Year(double year);
-double ThetaG(double epoch, deep_arg_t *deep_arg);
+double Julian_Date_of_Epoch(double epoch);
 double ThetaG_JD(double jd);
 void Calendar_Time_Now(struct tm *utc, struct tm *localtm);
-double Current_Daynum(void);
 double Theta(double julian_utc, double lon);
 /* earthtrack.c */
-double Arc_Cos(double x, double y);
-void Visibility_to_Color(satellite_status_t *sat_status, char *color);
-void Range_Lat_Lon(satellite_status_t *sat_status, int azim, double *range_lat, double *range_lon);
 int Display_Satellite(satellite_status_t *sat_status);
 int Config_Xplanet(observer_status_t *obs_status);
 /* gridloc.c */
 void Position_to_Grid_Locator(double lon, double lat, char *grid_loc);
 void Grid_Locator_to_Position(char *grid_loc, double *lon, double *lat);
-void Degrees_to_DMS(double deg, int *ideg, int *imin, int *isec);
-void DMS_to_Degrees(int ideg, int imin, int isec, double *deg);
-void Bearing_Distance(double lon_a, double lat_a, double lon_b, double lat_b, double *bearing, double *distance);
 gboolean Locator_Valid(char *locator);
 /* gui.c */
-void Show_Observer_Status(GtkWidget *window, observer_status_t *obs_status);
-void Show_Satellite_Data(GtkWidget *window, satellite_status_t *sat_status);
+void Show_Observer_Status(GtkBuilder *builder, int active_window, observer_status_t *obs_status);
+void Show_Satellite_Data(GtkBuilder *builder, int active_window, satellite_status_t *sat_status);
 void Show_Multiobserver_Status(GtkTreeView *multiloc_treeview, GtkTreeStore *store, satellite_status_t *mxsat_status);
 void Show_Satellite_Status(satellite_status_t *sat_status);
 void Show_Multisatellite_Status(GtkTreeView *multisat_treeview, satellite_status_t *multisat_status);
-void Show_Pass_Predictions(GtkWidget *pass_predict, satellite_status_t *sat_status, pass_data_t *pass_data, int num);
-void Show_Illumination_Predictions(double *jdate, int *illum);
+void Show_Pass_Predict(cairo_t *cr, GtkBuilder *pass_predict_builder, satellite_status_t *sat_status, pass_data_t *pass_data, int pnum);
+void Show_Illumination_Predict(cairo_t *cr, double *jdate, int *illum);
 void Show_Rotor_Control(double azim, double elev, int resol);
-void Show_CAT_Control(tcvr_status_t *tcvr_status);
+void Show_CAT_Control(transceiver_status_t *tcvr_status);
 gboolean Show_Offset_Calibration(gpointer data);
 gboolean Show_Fullscale_Calibration(gpointer data);
-void Set_GC_Attributes(GdkGC *gc, int red, int green, int blue, gint line_width, GtkWidget *widget);
 void Set_Doppler_Label(gchar *markup);
 /* input.c */
 char *Load_Database_Tle_Data(void);
-void Convert_Satellite_Data(char *tle_set, elem_set_t *elem_set);
-void Load_Tle_Set(char *sat_name, elem_set_t *sat_elem_set);
+void Load_Tle_Set(char *sat_name, element_set_t *sat_elem_set);
+void Set_Accessibility_Flags(element_set_t *sat_elem_set, observer_status_t *obs_status, satellite_status_t *sat_status );
 char *Read_Transponder_Data(char *sat_name);
 unsigned char Read_Operating_Mode(char *line);
-void Find_New_Satellite(int which, elem_set_t *sat_elem_set, satellite_status_t *sat_status, observer_status_t *obs_status);
-void New_Status(gboolean new_sat, elem_set_t *sat_elem_set, satellite_status_t *sat_status, observer_status_t *obs_status);
-void Set_Accessibility_Flags(elem_set_t *sat_elem_set, observer_status_t *obs_status, satellite_status_t *sat_status);
-int Aos_Possible(elem_set_t *sat_elem_set, observer_status_t *obs_status);
-int Satellite_Decayed(elem_set_t *sat_elem_set, double julian_utc);
-int Satellite_Geostationary(elem_set_t *sat_elem_set);
-int Checksum_Good(char *tle_set);
-gboolean Good_Elements(char *tle_set);
+void Find_New_Satellite(int which, element_set_t *sat_elem_set, satellite_status_t *sat_status, observer_status_t *obs_status);
+void New_Status(gboolean new_sat, element_set_t *sat_elem_set, satellite_status_t *sat_status, observer_status_t *obs_status);
 char *Load_Observer_Data(void);
 void Load_Observer_Set(char *loc_name, observer_status_t *obs_status);
 void Save_Location(observer_status_t *obs_status);
-int Load_Line(char *buff, FILE *pfile, int max_chr, char *messg, gboolean eof_err);
 /* interface.c */
-GtkWidget *create_sat_track(void);
-GtkWidget *create_multi_sat(void);
-GtkWidget *create_pass_pred(void);
-GtkWidget *create_multi_loc(void);
-GtkWidget *create_illum_pred(void);
-GtkWidget *create_error_dialog(void);
-GtkWidget *create_calibration(void);
-GtkWidget *create_main_menu(void);
-GtkWidget *create_azel_dialog(void);
-GtkWidget *create_loc_dialog(void);
+GtkWidget *Builder_Get_Object(GtkBuilder *builder, gchar *name);
+GtkWidget *create_satellite_track(GtkBuilder **builder);
+GtkWidget *create_multi_sat(GtkBuilder **builder);
+GtkWidget *create_pass_pred(GtkBuilder **builder);
+GtkWidget *create_multi_loc(GtkBuilder **builder);
+GtkWidget *create_illum_pred(GtkBuilder **builder);
+GtkWidget *create_error_dialog(GtkBuilder **builder);
+GtkWidget *create_calibration(GtkBuilder **builder);
+GtkWidget *create_popup_menu(GtkBuilder **builder);
+GtkWidget *create_azel_dialog(GtkBuilder **builder);
+GtkWidget *create_loc_dialog(GtkBuilder **builder);
 /* main.c */
 int main(int argc, char *argv[]);
 gboolean Load_Config(gpointer data);
 /* math_func.c */
-int Sign(double arg);
 double Sqr(double arg);
-double Cube(double arg);
 double Radians(double arg);
 double Degrees(double arg);
 double ArcSin(double arg);
-double ArcCos(double arg);
 void Magnitude(vector_t *v);
-void Vec_Add(vector_t *v1, vector_t *v2, vector_t *v3);
 void Vec_Sub(vector_t *v1, vector_t *v2, vector_t *v3);
 void Scalar_Multiply(double k, vector_t *v1, vector_t *v2);
 void Scale_Vector(double k, vector_t *v);
 double Dot(vector_t *v1, vector_t *v2);
 double Angle(vector_t *v1, vector_t *v2);
-void Cross(vector_t *v1, vector_t *v2, vector_t *v3);
-void Normalize(vector_t *v);
 double AcTan(double sinx, double cosx);
 double FMod2p(double x);
 double Modulus(double arg1, double arg2);
 double Frac(double arg);
-int Round(double arg);
-double Int(double arg);
 void Convert_Sat_State(kinetics_t *sat_kinetics);
 double Footprint(vector_t *pos);
 double Atof(const char *nptr);
 /* mode.c */
 gboolean Central_Mode(gpointer data);
-void Single_Satellite_Mode(elem_set_t *sat_elem_set, observer_status_t *obs_status, satellite_status_t *sat_status);
-void Multi_Satellite_Mode(elem_set_t *sat_elem_set, observer_status_t *obs_status, satellite_status_t *sat_status);
-void Multi_Observer_Mode(elem_set_t *sat_elem_set, observer_status_t *obs_status, satellite_status_t *sat_status);
-void Pass_Prediction_Mode(elem_set_t *sat_elem_set, observer_status_t *obs_status, satellite_status_t *sat_status);
-void Illumination_Prediction_Mode(elem_set_t *sat_elem_set, observer_status_t *obs_status, satellite_status_t *sat_status);
-void Calculate_Satellite_Status(double julian_utc, elem_set_t *sat_elem_set, kinetics_t *solar_kinetics, kinetics_t *obs_kinetics, observer_status_t *obs_status, satellite_status_t *sat_status);
+void Pass_Predict_Mode(cairo_t *cr);
+void Illumination_Predict_Mode(cairo_t *cr);
+void Draw_Illum_Predict(cairo_t *cr);
 void Manual_Position_Rotors(int azim, int elev);
-void Auto_Track(double julian_utc, satellite_status_t *sat_status);
 int isModeSet(int flag);
 int isModeClear(int flag);
 void Set_Mode(int flag);
@@ -730,22 +722,17 @@ void Clear_Mode(int flag);
 void Toggle_Mode(int flag);
 /* observer.c */
 void Calculate_User_PosVel(double time, observer_status_t *obs_status, kinetics_t *obs_kinetics);
-void Calculate_LatLonAlt(double time, vector_t *pos, geodetic_t *geodetic);
 void Calculate_Observer(kinetics_t *sat_kinetics, observer_status_t *obs_status, kinetics_t *obs_kinetics, vector_t *obs_set);
-void Calculate_RADec(double time, kinetics_t *sat_kinetics, observer_status_t *obs_status, kinetics_t *obs_kinetics, vector_t *obs_set);
 void RaDec_to_AzEl(double ra, double dec, double theta, geodetic_t *obs_geodetic, vector_t *lunar_set);
 void RaDec_to_Topocentric(double ra, double dec, vector_t *topocentric);
-double Find_Horizon_Crossing(double julian_utc, elem_set_t *sat_elem_set, observer_status_t *obs_status, satellite_status_t *sat_status);
-void Find_Next_AOS_LOS(double julian_utc, elem_set_t *sat_elem_set, observer_status_t *obs_status, satellite_status_t *sat_status);
-void Calculate_Orbit(double julian_utc, elem_set_t *sat_elem_set, geodetic_t *sat_geodetic, kinetics_t *sat_kinetics, satellite_status_t *sat_status, observer_status_t *obs_status, kinetics_t *obs_kinetics, vector_t *obs_set);
+void Find_Next_AOS_LOS(double julian_utc, element_set_t *sat_elem_set, observer_status_t *obs_status, satellite_status_t *sat_status);
+void Calculate_Orbit(double julian_utc, element_set_t *sat_elem_set, geodetic_t *sat_geodetic, kinetics_t *sat_kinetics, satellite_status_t *sat_status, observer_status_t *obs_status, kinetics_t *obs_kinetics, vector_t *obs_set);
 /* plots.c */
-void Draw_Plotting_Frame(GtkWidget *drawingarea, GdkRectangle *rect, gchar *title, int nhor, int nvert);
-void Draw_Graph(GtkWidget *drawingarea, GdkRectangle *rect, double *a, double *b, double amax, double amin, double bmax, double bmin, int nval);
+void Draw_Plotting_Frame(cairo_t *cr, GtkWidget *drawingarea, GdkRectangle *rect, gchar *title, int nhor, int nvert);
+void Draw_Graph(cairo_t *cr, GtkWidget *drawingarea, GdkRectangle *rect, double *a, double *b, double amax, double amin, double bmax, double bmin, int nval);
 void Cairo_Draw_Lines(cairo_t *cr, GdkPoint *points, int npoints);
 /* rotor.c */
 gboolean Open_Rotor_Serial(void);
-int Write_Rotor_Serial(char *ch);
-char Read_Rotor_Serial(void);
 void Close_Rotor_Serial(void);
 void Rotor_Send_String(char *strn);
 void Rotor_Read_String(char *strn, int len);
@@ -754,22 +741,14 @@ void Rotor_Read_Direction(int *azim, int *elev);
 void Enable_Tracking(void);
 void Disable_Tracking(void);
 /* sgp4unit.c */
-int sgp4init(const int satn, const double epoch, elem_set_t *elem_set);
-int sgp4(elem_set_t *elem_set, double tsince, kinetics_t *kinetics);
-double gstime(double jdut1);
+int sgp4init(const int satn, const double epoch, element_set_t *elem_set);
+int sgp4(element_set_t *elem_set, double tsince, kinetics_t *kinetics);
 void getgravconst(void);
 /* shared.c */
 /* solar_lunar.c */
 void Calculate_Solar_Position(double time, kinetics_t *solar_kinetics);
 int Satellite_Eclipsed(kinetics_t *sat_kinetics, kinetics_t *sol_kinetics, double *depth);
-void Lunar_Position(double daynum, geodetic_t *obs_geodetic, vector_t *lunar_set);
 void Calculate_Moon_Position(double julian_utc, observer_status_t *obs_status, kinetics_t *obs_kinetics);
-/* support.c */
-GtkWidget *lookup_widget(GtkWidget *widget, const gchar *widget_name);
-void add_pixmap_directory(const gchar *directory);
-GtkWidget *create_pixmap(GtkWidget *widget, const gchar *filename);
-GdkPixbuf *create_pixbuf(const gchar *filename);
-void glade_set_atk_action_description(AtkAction *action, const gchar *action_name, const gchar *description);
 /* utils.c */
 char *Abort_On_Error(int why);
 void Cleanup(void);
@@ -785,9 +764,10 @@ void Clear_SatFlag(satellite_status_t *sat_status, int flag);
 void Usage(void);
 void Strlcpy(char *dest, const char *src, size_t n);
 void Strlcat(char *dest, const char *src, size_t n);
+int Load_Line(char *buff, FILE *pfile, int max_chr, char *messg, gboolean eof_err);
 void mem_alloc(void **ptr, size_t req, gchar *str);
 void mem_realloc(void **ptr, size_t req, gchar *str);
 void free_ptr(void **ptr);
 
-#endif /* End of xsatcom.h */
+#endif
 
