@@ -1,16 +1,4 @@
-/*  input.c
- *
- *  Functions to do file i/o operations and carry out
- *  checking and preprocessing on data, mostly TLE sets,
- *  observer location and satellite databases
- */
-
 /*
- *  xsatcom: A X/GTK+ application to track satellites using the
- *  NORAD SGP4/SDP4 orbit calculation routines. The moon and sun
- *  are also tracked.
- *
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 2 of
@@ -29,6 +17,178 @@
 
 /*------------------------------------------------------------------*/
 
+/*  Convert_Satellite_Data()
+ *
+ *  Converts the strings in a raw two-line element
+ *  set to their intended numerical values. Processes
+ *  these values as needed by the SGP4 routines */
+
+  static void
+Convert_Satellite_Data( char *tle_set, element_set_t *elem_set )
+{
+  char buff[15];
+  double temp;
+
+  /** Decode Card 1 **/
+  /* Satellite's catalogue number */
+  Strlcpy( buff, &tle_set[2], 6 );
+  elem_set->satnum = atoi(buff);
+
+  /* International Designator for satellite */
+  Strlcpy( elem_set->idesg, &tle_set[9], 9 );
+  if( elem_set->idesg[7] == ' ' ) elem_set->idesg[7] = '\0';
+  if( elem_set->idesg[6] == ' ' ) elem_set->idesg[6] = '\0';
+
+  /* Satellite's epoch */
+  Strlcpy( buff, &tle_set[18], 15 );
+  elem_set->jdsatepoch = Atof(buff);
+
+  /* Satellite's First Time Derivative */
+  Strlcpy( buff, &tle_set[33], 11 );
+  elem_set->ndot = Atof(buff);
+
+  /* Satellite's Second Time Derivative */
+  Strlcpy( buff, &tle_set[44], 2 );
+  buff[1] = '.';
+  Strlcpy( &buff[2], &tle_set[45], 6 );
+  buff[7] = 'E';
+  Strlcpy( &buff[8], &tle_set[50], 3 );
+  elem_set->nddot = Atof(buff);
+
+  /* Satellite's bstar drag term */
+  Strlcpy( buff, &tle_set[53], 2 );
+  buff[1] = '.';
+  Strlcpy( &buff[2], &tle_set[54], 6 );
+  buff[7] = 'E';
+  Strlcpy( &buff[8], &tle_set[59], 3 );
+  elem_set->bstar = Atof(buff);
+
+  /* Element Number */
+  Strlcpy( buff, &tle_set[64], 5 );
+  elem_set->elset = atoi(buff);
+
+  /** Decode Card 2 **/
+  /* Satellite's Orbital Inclination (degrees) */
+  Strlcpy( buff, &tle_set[77], 9 );
+  elem_set->inclo = Atof(buff);
+
+  /* Satellite's RAAN (degrees) */
+  Strlcpy( buff, &tle_set[86], 9 );
+  elem_set->nodeo = Atof(buff);
+
+  /* Satellite's Orbital Eccentricity */
+  buff[0] = '.';
+  Strlcpy( &buff[1], &tle_set[95], 8 );
+  elem_set->ecco = Atof(buff);
+
+  /* Satellite's Argument of Perigee (degrees) */
+  Strlcpy( buff, &tle_set[103], 9 );
+  elem_set->argpo = Atof(buff);
+
+  /* Satellite's Mean Anomaly of Orbit (degrees) */
+  Strlcpy( buff, &tle_set[112], 9 );
+  elem_set->mo = Atof(buff);
+
+  /* Satellite's Mean Motion (rev/day) */
+  Strlcpy( buff, &tle_set[121], 11 );
+  elem_set->no = Atof(buff);
+
+  /* Satellite's Revolution number at epoch */
+  Strlcpy( buff, &tle_set[132], 6 );
+  elem_set->revnum = Atof(buff);
+
+  /* Preprocess tle set */
+  elem_set->nodeo = Radians( elem_set->nodeo );
+  elem_set->argpo = Radians( elem_set->argpo );
+  elem_set->mo    = Radians( elem_set->mo );
+  elem_set->inclo = Radians( elem_set->inclo );
+
+  temp = twopi/xmnpda/xmnpda;
+
+  elem_set->no    *= temp*xmnpda;
+  elem_set->ndot  *= temp;
+  elem_set->nddot *= temp/xmnpda;
+
+  // ---------------- initialize the orbit at sgp4epoch -------------------
+  sgp4init( elem_set->satnum, elem_set->jdsatepoch-2433281.5, elem_set );
+
+} /* Convert_Satellite_Data */
+
+/*------------------------------------------------------------------*/
+
+/*  Checksum_Good()
+ *
+ *  Calculates the checksum mod 10 of a line from a TLE set and
+ *  returns 1 if it compares with checksum in column 68, else 0.
+ *  tle_set is a character string holding the two lines read
+ *  from a text file containing NASA format Keplerian elements.
+ */
+
+  static int
+Checksum_Good( char *tle_set )
+{
+  int i, check_digit, value, checksum = 0;
+
+  for(i = 0; i < 68; i++)
+  {
+	if( (tle_set[i] >= '0') && (tle_set[i] <= '9') )
+	  value = tle_set[i] - '0';
+	else if( tle_set[i] == '-' )
+	  value = 1;
+	else
+	  value = 0;
+
+	checksum += value;
+
+  } /* End for(i = 0; i < 68; i++) */
+
+  checksum %= 10;
+  check_digit = tle_set[68] - '0';
+
+  return( checksum == check_digit );
+} /* Function Checksums_Good */
+
+/*------------------------------------------------------------------*/
+
+/*  Good_Elements()
+ *
+ *  Carries out various checks on a TLE set to verify its validity.
+ *  tle_set is a character string holding the two lines read
+ *  from a text file containing NASA format Keplerian elements.
+ */
+
+  static gboolean
+Good_Elements( char *tle_set )
+{
+  /* Verify checksum of both lines of a TLE set */
+  if( !Checksum_Good(&tle_set[0]) || !Checksum_Good(&tle_set[69]) )
+	return( FALSE );
+
+  /* Check the line number of each line */
+  if( (tle_set[0] != '1') || (tle_set[69] != '2') )
+	return( FALSE );
+
+  /* Verify that Satellite Number is same in both lines */
+  if( strncmp(&tle_set[2], &tle_set[71], 5) != 0 )
+	return( FALSE );
+
+  /* Check that various elements are in the right place */
+  if( ((tle_set[ 23] != '.') && (tle_set[ 23] != ',')) ||
+	  ((tle_set[ 34] != '.') && (tle_set[ 34] != ',')) ||
+	  ((tle_set[ 80] != '.') && (tle_set[ 80] != ',')) ||
+	  ((tle_set[ 89] != '.') && (tle_set[ 89] != ',')) ||
+	  ((tle_set[106] != '.') && (tle_set[106] != ',')) ||
+	  ((tle_set[115] != '.') && (tle_set[115] != ',')) ||
+	  ((tle_set[123] != '.') && (tle_set[123] != ',')) ||
+	  ((strncmp(&tle_set[61], " 0 ", 3) != 0)) )
+	return( FALSE );
+
+  return( TRUE );
+
+} /* Function Good_Elements */
+
+/*------------------------------------------------------------------*/
+
 /*  Load_Database_Tle_Data()
  *
  *  Loads the TLE sets of all satellites in the xsatcom.sat
@@ -129,10 +289,10 @@ Load_Database_Tle_Data( void )
   }
 
   /* Allocate memory to TLE database buffer */
-  mem_realloc( (void **)&gbl_elem_sets,
-	  sizeof(elem_set_t) * (size_t)num_sats,
-	  _("for gbl_elem_sets in Load_Database_Tle_Data()") );
-  if( gbl_elem_sets == NULL )
+  mem_realloc( (void **)&element_sets,
+	  sizeof(element_set_t) * (size_t)num_sats,
+	  _("for element_sets in Load_Database_Tle_Data()") );
+  if( element_sets == NULL )
   {
 	fclose( tle_file );
 	return( "!OK" );
@@ -233,7 +393,7 @@ Load_Database_Tle_Data( void )
 	/* Check for duplicate TLE set before entering to buffer */
 	dup_flg = 0;
 	for( icp = 0; icp < num_ld; icp++ )
-	  if( strncmp(gbl_elem_sets[icp].name,
+	  if( strncmp(element_sets[icp].name,
 			name, strlen(name)) == 0 )
 		dup_flg = 1;
 
@@ -241,8 +401,8 @@ Load_Database_Tle_Data( void )
 	if( !dup_flg )
 	{
 	  /* Enter name in TLE structure */
-	  Strlcpy( gbl_elem_sets[num_ld].name, name,
-		  sizeof(gbl_elem_sets[num_ld].name) );
+	  Strlcpy( element_sets[num_ld].name, name,
+		  sizeof(element_sets[num_ld].name) );
 
 	  /* Check TLE set and Abort -3 if not valid */
 	  if( !Good_Elements(tle_set) )
@@ -255,11 +415,11 @@ Load_Database_Tle_Data( void )
 	  }
 
 	  /* Convert the TLE set to orbital elements */
-	  Convert_Satellite_Data( tle_set, &gbl_elem_sets[num_ld] );
+	  Convert_Satellite_Data( tle_set, &element_sets[num_ld] );
 
 	  /* Convert satellite's epoch time to Julian  */
-	  gbl_elem_sets[num_ld].jdsatepoch =
-		Julian_Date_of_Epoch(gbl_elem_sets[num_ld].jdsatepoch);
+	  element_sets[num_ld].jdsatepoch =
+		Julian_Date_of_Epoch(element_sets[num_ld].jdsatepoch);
 
 	  num_ld++;
 
@@ -267,7 +427,7 @@ Load_Database_Tle_Data( void )
 
   } /* End of for( idxa = 0; idxa < num_sats; idxa++ ) */
 
-  gbl_num_sets = num_ld;
+  num_sets = num_ld;
 
   fclose( tle_file );
   fclose( sat_file );
@@ -278,112 +438,13 @@ Load_Database_Tle_Data( void )
 
 /*------------------------------------------------------------------*/
 
-/*  Convert_Satellite_Data()
- *
- *  Converts the strings in a raw two-line element
- *  set to their intended numerical values. Processes
- *  these values as needed by the SGP4 routines */
-
-  void
-Convert_Satellite_Data( char *tle_set, elem_set_t *elem_set )
-{
-  char buff[15];
-  double temp;
-
-  /** Decode Card 1 **/
-  /* Satellite's catalogue number */
-  Strlcpy( buff, &tle_set[2], 6 );
-  elem_set->satnum = atoi(buff);
-
-  /* International Designator for satellite */
-  Strlcpy( elem_set->idesg, &tle_set[9], 9 );
-  if( elem_set->idesg[7] == ' ' ) elem_set->idesg[7] = '\0';
-  if( elem_set->idesg[6] == ' ' ) elem_set->idesg[6] = '\0';
-
-  /* Satellite's epoch */
-  Strlcpy( buff, &tle_set[18], 15 );
-  elem_set->jdsatepoch = Atof(buff);
-
-  /* Satellite's First Time Derivative */
-  Strlcpy( buff, &tle_set[33], 11 );
-  elem_set->ndot = Atof(buff);
-
-  /* Satellite's Second Time Derivative */
-  Strlcpy( buff, &tle_set[44], 2 );
-  buff[1] = '.';
-  Strlcpy( &buff[2], &tle_set[45], 6 );
-  buff[7] = 'E';
-  Strlcpy( &buff[8], &tle_set[50], 3 );
-  elem_set->nddot = Atof(buff);
-
-  /* Satellite's bstar drag term */
-  Strlcpy( buff, &tle_set[53], 2 );
-  buff[1] = '.';
-  Strlcpy( &buff[2], &tle_set[54], 6 );
-  buff[7] = 'E';
-  Strlcpy( &buff[8], &tle_set[59], 3 );
-  elem_set->bstar = Atof(buff);
-
-  /* Element Number */
-  Strlcpy( buff, &tle_set[64], 5 );
-  elem_set->elset = atoi(buff);
-
-  /** Decode Card 2 **/
-  /* Satellite's Orbital Inclination (degrees) */
-  Strlcpy( buff, &tle_set[77], 9 );
-  elem_set->inclo = Atof(buff);
-
-  /* Satellite's RAAN (degrees) */
-  Strlcpy( buff, &tle_set[86], 9 );
-  elem_set->nodeo = Atof(buff);
-
-  /* Satellite's Orbital Eccentricity */
-  buff[0] = '.';
-  Strlcpy( &buff[1], &tle_set[95], 8 );
-  elem_set->ecco = Atof(buff);
-
-  /* Satellite's Argument of Perigee (degrees) */
-  Strlcpy( buff, &tle_set[103], 9 );
-  elem_set->argpo = Atof(buff);
-
-  /* Satellite's Mean Anomaly of Orbit (degrees) */
-  Strlcpy( buff, &tle_set[112], 9 );
-  elem_set->mo = Atof(buff);
-
-  /* Satellite's Mean Motion (rev/day) */
-  Strlcpy( buff, &tle_set[121], 11 );
-  elem_set->no = Atof(buff);
-
-  /* Satellite's Revolution number at epoch */
-  Strlcpy( buff, &tle_set[132], 6 );
-  elem_set->revnum = Atof(buff);
-
-  /* Preprocess tle set */
-  elem_set->nodeo = Radians( elem_set->nodeo );
-  elem_set->argpo = Radians( elem_set->argpo );
-  elem_set->mo    = Radians( elem_set->mo );
-  elem_set->inclo = Radians( elem_set->inclo );
-
-  temp = twopi/xmnpda/xmnpda;
-
-  elem_set->no    *= temp*xmnpda;
-  elem_set->ndot  *= temp;
-  elem_set->nddot *= temp/xmnpda;
-
-  // ---------------- initialize the orbit at sgp4epoch -------------------
-  sgp4init( elem_set->satnum, elem_set->jdsatepoch-2433281.5, elem_set );
-
-} /* Procedure Convert_Satellite_Data */
-
-/*------------------------------------------------------------------*/
-
 /*  Load_Tle_Set()
  *
  *  Loads the TLE set of a given satellite
  */
 
   void
-Load_Tle_Set( char *sat_name, elem_set_t *sat_elem_set )
+Load_Tle_Set( char *sat_name, element_set_t *sat_elem_set )
 {
   /* index for loops etc */
   int idx;
@@ -397,24 +458,24 @@ Load_Tle_Set( char *sat_name, elem_set_t *sat_elem_set )
 	sat_name[NAME_SIZE - 2] = '\0';
 
   /* Look for a matching satellite name in database */
-  for( idx = 0; idx < gbl_num_sets; idx++ )
-	if( strncmp(gbl_elem_sets[idx].name,
+  for( idx = 0; idx < num_sets; idx++ )
+	if( strncmp(element_sets[idx].name,
 		  sat_name, strlen(sat_name)) == 0 )
 	{
 	  /* Load TLE set on match */
-	  *sat_elem_set = gbl_elem_sets[idx];
-	  gbl_set_idx = idx;
+	  *sat_elem_set = element_sets[idx];
+	  set_idx = idx;
 	  break;
 	}
 
   /* If no matching name, load 1st TLE set as default */
   if( strcmp(sat_elem_set->name, "") == 0 )
   {
-	*sat_elem_set = gbl_elem_sets[0];
-	gbl_set_idx = 0;
+	*sat_elem_set = element_sets[0];
+	set_idx = 0;
   }
 
-  Config_Xplanet( &gbl_obs_status );
+  Config_Xplanet( &observer_status );
 
 } /* End of Load_Tle_Set() */
 
@@ -444,11 +505,10 @@ Read_Transponder_Data( char *sat_name )
 
 
   /* Allocate memory to transponder mode data buffer */
-  if( gbl_sat_mode == NULL )
-	mem_alloc( (void **)&gbl_sat_mode,
-		sizeof(satellite_mode_t),
-		_("for gbl_sat_mode in Read_Transponder_Data()") );
-  if( gbl_sat_mode == NULL ) return( "!OK" );
+  if( satellite_mode == NULL )
+	mem_alloc( (void **)&satellite_mode, sizeof(satellite_mode_t),
+		_("for satellite_mode in Read_Transponder_Data()") );
+  if( satellite_mode == NULL ) return( "!OK" );
 
   /* Setup 'home' directory path */
   Strlcpy( home_dir, getenv("HOME"), sizeof(home_dir) );
@@ -473,11 +533,11 @@ Read_Transponder_Data( char *sat_name )
 	/* Break if sat_name found in database */
 	ret = Load_Line( line, sat_file, 80, "xsatcom.sat", FALSE );
 	if( ret == ERROR ) return( Abort_On_Error(-1) );
-	if( strncmp( &line[1], sat_name, idx ) == 0 )
+	if( strncmp( &line[1], sat_name, (unsigned long)idx ) == 0 )
 	  break;
   }
   while( ret != EOF_NORM );
-  gbl_num_modes = 0;
+  num_modes = 0;
 
   /* Look for transponder mode and frequency data.  */
   /* Frequencies are specified in float MHz and are */
@@ -490,10 +550,10 @@ Read_Transponder_Data( char *sat_name )
   while( TRUE )
   {
 	/* Clear satellite mode flags and name */
-	gbl_sat_mode[gbl_num_modes].flags = NO_TRANSPONDER;
-	Strlcpy( gbl_sat_mode[gbl_num_modes].mode_name,	"No Mode!",
-		sizeof(gbl_sat_mode[gbl_num_modes].mode_name) );
-	gbl_sat_mode[gbl_num_modes].tone_freq = 0;
+	satellite_mode[num_modes].flags = NO_TRANSPONDER;
+	Strlcpy( satellite_mode[num_modes].mode_name,	"No Mode!",
+		sizeof(satellite_mode[num_modes].mode_name) );
+	satellite_mode[num_modes].tone_freq = 0;
 
 	/* Look for a 'Mode' entry, return if none */
 	if( strncmp(line, "Mode", 4) == 0 )
@@ -518,8 +578,8 @@ Read_Transponder_Data( char *sat_name )
 
 	/* Enter mode name in buffer */
 	if( idx > 70 ) idx = 70; /* Avoid line buf overrun */
-	Strlcpy( gbl_sat_mode[gbl_num_modes].mode_name, &line[idx],
-		sizeof(gbl_sat_mode[gbl_num_modes].mode_name) );
+	Strlcpy( satellite_mode[num_modes].mode_name, &line[idx],
+		sizeof(satellite_mode[num_modes].mode_name) );
 
 	/* Read satellite's transponder data if available */
 	/* Read next line in xsatcom.sat */
@@ -533,7 +593,7 @@ Read_Transponder_Data( char *sat_name )
 	  /* Abort if no Mode data entry due to EOF or "End" */
 	  if( ret == EOF_NORM )
 	  {
-		if( gbl_sat_mode[gbl_num_modes].flags == NO_TRANSPONDER )
+		if( satellite_mode[num_modes].flags == NO_TRANSPONDER )
 		{
 		  fclose( sat_file );
 		  return( Abort_On_Error(-14) );
@@ -549,47 +609,47 @@ Read_Transponder_Data( char *sat_name )
 	  if( strncmp(line, "Uplink", 6) == 0 )
 	  {
 		/* Get Tx freq and Mode */
-		gbl_sat_mode[gbl_num_modes].uplink_freq =
+		satellite_mode[num_modes].uplink_freq =
 		  (int)( Atof(&line[6]) * 1.0E6 + 0.5E-6 );
-		gbl_sat_mode[gbl_num_modes].tx_mode = Read_Operating_Mode( line );
-		gbl_sat_mode[gbl_num_modes].flags |= UPLINK_DATA;
-		if( !(gbl_sat_mode[gbl_num_modes].flags & TXFREQ_DATA) )
-		  gbl_sat_mode[gbl_num_modes].tx_freq =
-			gbl_sat_mode[gbl_num_modes].uplink_freq;
+		satellite_mode[num_modes].tx_mode = Read_Operating_Mode( line );
+		satellite_mode[num_modes].flags |= UPLINK_DATA;
+		if( !(satellite_mode[num_modes].flags & TXFREQ_DATA) )
+		  satellite_mode[num_modes].tx_freq =
+			satellite_mode[num_modes].uplink_freq;
 
 	  } /* if(strcmp(line, "Transmit") == 0) */
 
 	  /* Look for CTCSS tone entry */
 	  if( strncmp(line, "Tone", 4) == 0 )
-		gbl_sat_mode[gbl_num_modes].tone_freq = (int)(10.0 * Atof(&line[4]));
+		satellite_mode[num_modes].tone_freq = (int)(10.0 * Atof(&line[4]));
 
 	  /* Look for separate Tx freq which may not be same as uplink freq */
 	  if( strncmp(line, "Transmit", 8) == 0 )
 	  {
-		gbl_sat_mode[gbl_num_modes].tx_freq =
+		satellite_mode[num_modes].tx_freq =
 		  (int)( Atof(&line[8]) * 1.0E6 + 0.5E-6 );
-		gbl_sat_mode[gbl_num_modes].flags |= TXFREQ_DATA;
+		satellite_mode[num_modes].flags |= TXFREQ_DATA;
 	  }
 
 	  /* Look for a "Downlink" entry, read freq and mode */
 	  if( strncmp(line, "Downlink", 8) == 0 )
 	  {
-		gbl_sat_mode[gbl_num_modes].dnlink_freq =
+		satellite_mode[num_modes].dnlink_freq =
 		  (int)( Atof(&line[8]) * 1.0E6 + 0.5E-6 );
-		gbl_sat_mode[gbl_num_modes].rx_mode =
+		satellite_mode[num_modes].rx_mode =
 		  Read_Operating_Mode( line );
-		gbl_sat_mode[gbl_num_modes].flags |= DNLINK_DATA;
-		if( !(gbl_sat_mode[gbl_num_modes].flags & RXFREQ_DATA) )
-		  gbl_sat_mode[gbl_num_modes].rx_freq =
-			gbl_sat_mode[gbl_num_modes].dnlink_freq;
+		satellite_mode[num_modes].flags |= DNLINK_DATA;
+		if( !(satellite_mode[num_modes].flags & RXFREQ_DATA) )
+		  satellite_mode[num_modes].rx_freq =
+			satellite_mode[num_modes].dnlink_freq;
 	  } /* if(strcmp(line, "Downlink") == 0) */
 
 	  /* Look for 'Receive' entry, read freq */
 	  if( strncmp(line, "Receive", 7) == 0 )
 	  {
-		gbl_sat_mode[gbl_num_modes].rx_freq =
+		satellite_mode[num_modes].rx_freq =
 		  (int)( Atof(&line[7]) * 1.0E6 + 0.5E-6 );
-		gbl_sat_mode[gbl_num_modes].flags |= RXFREQ_DATA;
+		satellite_mode[num_modes].flags |= RXFREQ_DATA;
 	  }
 
 	  /* Look for a 'Passband' entry */
@@ -597,9 +657,9 @@ Read_Transponder_Data( char *sat_name )
 	  {
 		/* Look for passband type entry */
 		if( strstr(line, "invert") != NULL )
-		  gbl_sat_mode[gbl_num_modes].flags &= ~PASSBAND_NORM;
+		  satellite_mode[num_modes].flags &= ~PASSBAND_NORM;
 		else if( strstr(line, "normal") != NULL )
-		  gbl_sat_mode[gbl_num_modes].flags |= PASSBAND_NORM;
+		  satellite_mode[num_modes].flags |= PASSBAND_NORM;
 		else
 		{
 		  fclose( sat_file );
@@ -607,19 +667,19 @@ Read_Transponder_Data( char *sat_name )
 		}
 	  } /* if( strcmp(line, "Passband") == 0 ) */
 	  else
-		gbl_sat_mode[gbl_num_modes].flags |= PASSBAND_NORM;
+		satellite_mode[num_modes].flags |= PASSBAND_NORM;
 
 	  /* Read beacon frequency */
 	  if( strncmp(line, "Beacon", 6) == 0 )
 	  {
-		gbl_sat_mode[gbl_num_modes].bcn_freq =
+		satellite_mode[num_modes].bcn_freq =
 		  (int)( Atof(&line[6]) * 1.0E6 + 0.5E-6 );
-		gbl_sat_mode[gbl_num_modes].bcn_mode =
+		satellite_mode[num_modes].bcn_mode =
 		  Read_Operating_Mode( line );
-		if( !(gbl_sat_mode[gbl_num_modes].flags & RXFREQ_DATA) )
-		  gbl_sat_mode[gbl_num_modes].rx_freq =
-			gbl_sat_mode[gbl_num_modes].bcn_freq;
-		gbl_sat_mode[gbl_num_modes].flags |= BEACON_DATA;
+		if( !(satellite_mode[num_modes].flags & RXFREQ_DATA) )
+		  satellite_mode[num_modes].rx_freq =
+			satellite_mode[num_modes].bcn_freq;
+		satellite_mode[num_modes].flags |= BEACON_DATA;
 	  } /* if( strncmp(line, "Beacon", 6) == 0 ) */
 
 	  /* Break if no more Mode data (Found next Mode or Name) */
@@ -632,17 +692,17 @@ Read_Transponder_Data( char *sat_name )
 		break;
 
 	} /* while( TRUE ) */
-	gbl_num_modes++;
+	num_modes++;
 
 	/* Next satellite name is found */
 	if( (line[0] == '[') || (ret == EOF_NORM) )
 	  break;
 
 	/* Reallocate modes buffer for more data */
-	mem_realloc( (void **)&gbl_sat_mode,
-		(size_t)(gbl_num_modes+1) * sizeof(satellite_mode_t),
-		_("for gbl_sat_mode in Read_Transponder_Data()") );
-	if( gbl_sat_mode == NULL ) return( "!OK" );
+	mem_realloc( (void **)&satellite_mode,
+		(size_t)(num_modes+1) * sizeof(satellite_mode_t),
+		_("for satellite_mode in Read_Transponder_Data()") );
+	if( satellite_mode == NULL ) return( "!OK" );
 
   } /* End of while( TRUE ) */
 
@@ -702,50 +762,114 @@ Read_Operating_Mode( char *line )
 
 /*------------------------------------------------------------------*/
 
-/*  Find_New_Satellite()
+/*  Aos_Possible()
  *
- *  Scrolls up/down in the TLE buffer to find a new satellite.
- *  The new satellite status is then displayed in main screen
+ *  This function returns a 1 if the satellite of interest
+ *  can ever rise above the horizon of the ground station
  */
 
-void
-Find_New_Satellite(
-	int which,
-	elem_set_t *sat_elem_set,
-	satellite_status_t *sat_status,
-	observer_status_t  *obs_status )
+  static int
+Aos_Possible( element_set_t *sat_elem_set, observer_status_t  *obs_status )
 {
-  switch( which ) /* How to search */
-  {
-	case FORWD_SATELLITE : /* Find next satellite */
-	  /* Input next TLE set from database */
-	  gbl_set_idx = ( ++gbl_set_idx == gbl_num_sets ? 0 : gbl_set_idx );
-	  *sat_elem_set = gbl_elem_sets[gbl_set_idx];
-	  break;
+  double incl, sma, apogee;
 
-	case BACK_SATELLITE : /* Find previous satellite */
-	  /* Input previous TLE set from database */
-	  gbl_set_idx = ( --gbl_set_idx < 0 ? gbl_num_sets-1 : gbl_set_idx );
-	  *sat_elem_set = gbl_elem_sets[gbl_set_idx];
-	  break;
+  incl = sat_elem_set->inclo;
+  if (incl >= pio2)
+	incl = pi-incl;
 
-	case FIRST_SATELLITE : /* Find first satellite */
-	  /* Input a TLE set from database */
-	  *sat_elem_set = gbl_elem_sets[0];
-	  gbl_set_idx = 0;
-	  break;
+  sma = 331.25*exp( log(1./sat_elem_set->no*twopi) * tothrd );
+  apogee = sma*(1. + sat_elem_set->ecco) - rc_data.radiusearthkm;
 
-	case LAST_SATELLITE : /* Find last satellite */
-	  /* Input a TLE set from database */
-	  *sat_elem_set = gbl_elem_sets[gbl_num_sets-1];
-	  gbl_set_idx = gbl_num_sets-1;
+  if( (acos(rc_data.radiusearthkm/(apogee+rc_data.radiusearthkm))+incl) >
+	  fabs(obs_status->obs_geodetic.lat) )
+	return 1;
+  else
+	return 0;
 
-  } /* End of switch( which ) */
+} /* End of Aos_Possible() */
 
-  /* Preprocess new satellite data */
-  New_Status( TRUE, sat_elem_set, sat_status, obs_status );
+/*------------------------------------------------------------------*/
 
-} /* End of Find_New_Satellite() */
+/*  Satellite_Decayed()
+ *
+ *  This function returns a 1 if it appears that the
+ *  satellite of interest has decayed at time 'julian_utc'
+ */
+
+  static int
+Satellite_Decayed( element_set_t *sat_elem_set, double julian_utc )
+{
+  double
+	drag,
+	test;
+
+  drag = ( sat_elem_set->ndot == 0. ? 1.E-8 : sat_elem_set->ndot ) * xmnpda;
+  test = sat_elem_set->jdsatepoch + ( (0.072722052-sat_elem_set->no)/(10.0*fabs(drag)) );
+
+  if( test < julian_utc )
+	return 1;
+  else
+	return 0;
+
+} /* End of Satellite_Decayed() */
+
+/*------------------------------------------------------------------*/
+
+/*  Satellite_Geostationary()
+ *
+ *  This function returns a 1 if the satellite of
+ *  interest appears to be in a geostationary orbit
+ */
+
+  static int
+Satellite_Geostationary( element_set_t *sat_elem_set )
+{
+  if( fabs(sat_elem_set->no - 0.0043751) < 1.3E-6 )
+	return 1;
+  else
+	return 0;
+
+} /* End of Satellite_Geostationary() */
+
+/*------------------------------------------------------------------*/
+
+/*  Set_Acessibility_Flags()
+ *
+ *  Checks whether satellite can be accessed and sets flags
+ */
+
+  void
+Set_Accessibility_Flags(
+	element_set_t *sat_elem_set,
+	observer_status_t  *obs_status,
+	satellite_status_t *sat_status )
+{
+  struct tm
+	utc,      /* Calendar date and time (UTC)   */
+	localtm;  /* Calendar date and time (local) */
+
+  double julian_utc;
+
+  /* Get UTC calendar and convert to Julian */
+  Calendar_Time_Now( &utc, &localtm );
+  julian_utc = Julian_Date( &utc );
+
+  if( Aos_Possible(sat_elem_set, obs_status) )
+	Clear_SatFlag( sat_status, SAT_INACCESSIBLE );
+  else
+	Set_SatFlag( sat_status, SAT_INACCESSIBLE | NO_AOS_LOS );
+
+  if( Satellite_Geostationary(sat_elem_set) )
+	Set_SatFlag( sat_status, SAT_GEOSTATIONARY | NO_AOS_LOS );
+  else
+	Clear_SatFlag( sat_status, SAT_GEOSTATIONARY );
+
+  if( Satellite_Decayed(sat_elem_set, julian_utc) )
+	Set_SatFlag( sat_status, SAT_DECAYED | NO_AOS_LOS );
+  else
+	Clear_SatFlag( sat_status, SAT_DECAYED );
+
+} /* End of Set_Acessibility_Flags() */
 
 /*------------------------------------------------------------------*/
 
@@ -755,10 +879,10 @@ Find_New_Satellite(
  *  a change of satellite or observer
  */
 
-void
+  void
 New_Status(
 	gboolean new_sat,
-	elem_set_t *sat_elem_set,
+	element_set_t *sat_elem_set,
 	satellite_status_t *sat_status,
 	observer_status_t  *obs_status )
 {
@@ -844,187 +968,50 @@ New_Status(
 
 /*------------------------------------------------------------------*/
 
-/*  Set_Acessibility_Flags()
+/*  Find_New_Satellite()
  *
- *  Checks whether satellite can be accessed and sets flags
+ *  Scrolls up/down in the TLE buffer to find a new satellite.
+ *  The new satellite status is then displayed in main screen
  */
 
-void
-Set_Accessibility_Flags(
-	elem_set_t *sat_elem_set,
-	observer_status_t  *obs_status,
-	satellite_status_t *sat_status )
+  void
+Find_New_Satellite(
+	int which,
+	element_set_t *sat_elem_set,
+	satellite_status_t *sat_status,
+	observer_status_t  *obs_status )
 {
-  struct tm
-	utc,      /* Calendar date and time (UTC)   */
-	localtm;  /* Calendar date and time (local) */
-
-  double julian_utc;
-
-  /* Get UTC calendar and convert to Julian */
-  Calendar_Time_Now( &utc, &localtm );
-  julian_utc = Julian_Date( &utc );
-
-  if( Aos_Possible(sat_elem_set, obs_status) )
-	Clear_SatFlag( sat_status, SAT_INACCESSIBLE );
-  else
-	Set_SatFlag( sat_status, SAT_INACCESSIBLE | NO_AOS_LOS );
-
-  if( Satellite_Geostationary(sat_elem_set) )
-	Set_SatFlag( sat_status, SAT_GEOSTATIONARY | NO_AOS_LOS );
-  else
-	Clear_SatFlag( sat_status, SAT_GEOSTATIONARY );
-
-  if( Satellite_Decayed(sat_elem_set, julian_utc) )
-	Set_SatFlag( sat_status, SAT_DECAYED | NO_AOS_LOS );
-  else
-	Clear_SatFlag( sat_status, SAT_DECAYED );
-
-} /* End of Set_Acessibility_Flags() */
-
-/*------------------------------------------------------------------*/
-
-/*  Aos_Possible()
- *
- *  This function returns a 1 if the satellite of interest
- *  can ever rise above the horizon of the ground station
- */
-
-  int
-Aos_Possible( elem_set_t *sat_elem_set, observer_status_t  *obs_status )
-{
-  double incl, sma, apogee;
-
-  incl = sat_elem_set->inclo;
-  if (incl >= pio2)
-	incl = pi-incl;
-
-  sma = 331.25*exp( log(1./sat_elem_set->no*twopi) * tothrd );
-  apogee = sma*(1. + sat_elem_set->ecco) - rc_data.radiusearthkm;
-
-  if( (acos(rc_data.radiusearthkm/(apogee+rc_data.radiusearthkm))+incl) >
-	  fabs(obs_status->obs_geodetic.lat) )
-	return 1;
-  else
-	return 0;
-
-} /* End of Aos_Possible() */
-
-/*------------------------------------------------------------------*/
-
-/*  Satellite_Decayed()
- *
- *  This function returns a 1 if it appears that the
- *  satellite of interest has decayed at time 'julian_utc'
- */
-
-  int
-Satellite_Decayed( elem_set_t *sat_elem_set, double julian_utc )
-{
-  double
-	drag,
-	test;
-
-  drag = ( sat_elem_set->ndot == 0. ? 1.E-8 : sat_elem_set->ndot ) * xmnpda;
-  test = sat_elem_set->jdsatepoch + ( (0.072722052-sat_elem_set->no)/(10.0*fabs(drag)) );
-
-  if( test < julian_utc )
-	return 1;
-  else
-	return 0;
-
-} /* End of Satellite_Decayed() */
-
-/*------------------------------------------------------------------*/
-
-/*  Satellite_Geostationary()
- *
- *  This function returns a 1 if the satellite of
- *  interest appears to be in a geostationary orbit
- */
-
-  int
-Satellite_Geostationary( elem_set_t *sat_elem_set )
-{
-  if( fabs(sat_elem_set->no - 0.0043751) < 1.3E-6 )
-	return 1;
-  else
-	return 0;
-
-} /* End of Satellite_Geostationary() */
-
-/*------------------------------------------------------------------*/
-
-/*  Checksum_Good()
- *
- *  Calculates the checksum mod 10 of a line from a TLE set and
- *  returns 1 if it compares with checksum in column 68, else 0.
- *  tle_set is a character string holding the two lines read
- *  from a text file containing NASA format Keplerian elements.
- */
-
-  int
-Checksum_Good( char *tle_set )
-{
-  int i, check_digit, value, checksum = 0;
-
-  for(i = 0; i < 68; i++)
+  switch( which ) /* How to search */
   {
-	if( (tle_set[i] >= '0') && (tle_set[i] <= '9') )
-	  value = tle_set[i] - '0';
-	else if( tle_set[i] == '-' )
-	  value = 1;
-	else
-	  value = 0;
+	case FORWD_SATELLITE : /* Find next satellite */
+	  /* Input next TLE set from database */
+	  set_idx = ( ++set_idx == num_sets ? 0 : set_idx );
+	  *sat_elem_set = element_sets[set_idx];
+	  break;
 
-	checksum += value;
+	case BACK_SATELLITE : /* Find previous satellite */
+	  /* Input previous TLE set from database */
+	  set_idx = ( --set_idx < 0 ? num_sets-1 : set_idx );
+	  *sat_elem_set = element_sets[set_idx];
+	  break;
 
-  } /* End for(i = 0; i < 68; i++) */
+	case FIRST_SATELLITE : /* Find first satellite */
+	  /* Input a TLE set from database */
+	  *sat_elem_set = element_sets[0];
+	  set_idx = 0;
+	  break;
 
-  checksum %= 10;
-  check_digit = tle_set[68] - '0';
+	case LAST_SATELLITE : /* Find last satellite */
+	  /* Input a TLE set from database */
+	  *sat_elem_set = element_sets[num_sets-1];
+	  set_idx = num_sets-1;
 
-  return( checksum == check_digit );
-} /* Function Checksums_Good */
+  } /* End of switch( which ) */
 
-/*------------------------------------------------------------------*/
+  /* Preprocess new satellite data */
+  New_Status( TRUE, sat_elem_set, sat_status, obs_status );
 
-/*  Good_Elements()
- *
- *  Carries out various checks on a TLE set to verify its validity.
- *  tle_set is a character string holding the two lines read
- *  from a text file containing NASA format Keplerian elements.
- */
-
-  gboolean
-Good_Elements( char *tle_set )
-{
-  /* Verify checksum of both lines of a TLE set */
-  if( !Checksum_Good(&tle_set[0]) || !Checksum_Good(&tle_set[69]) )
-	return( FALSE );
-
-  /* Check the line number of each line */
-  if( (tle_set[0] != '1') || (tle_set[69] != '2') )
-	return( FALSE );
-
-  /* Verify that Satellite Number is same in both lines */
-  if( strncmp(&tle_set[2], &tle_set[71], 5) != 0 )
-	return( FALSE );
-
-  /* Check that various elements are in the right place */
-  if( ((tle_set[ 23] != '.') && (tle_set[ 23] != ',')) ||
-	  ((tle_set[ 34] != '.') && (tle_set[ 34] != ',')) ||
-	  ((tle_set[ 80] != '.') && (tle_set[ 80] != ',')) ||
-	  ((tle_set[ 89] != '.') && (tle_set[ 89] != ',')) ||
-	  ((tle_set[106] != '.') && (tle_set[106] != ',')) ||
-	  ((tle_set[115] != '.') && (tle_set[115] != ',')) ||
-	  ((tle_set[123] != '.') && (tle_set[123] != ',')) ||
-	  ((strncmp(&tle_set[61], " 0 ", 3) != 0)) )
-	return( FALSE );
-
-  return( TRUE );
-
-} /* Function Good_Elements */
+} /* End of Find_New_Satellite() */
 
 /*------------------------------------------------------------------*/
 
@@ -1065,7 +1052,7 @@ Load_Observer_Data( void )
 	return( Abort_On_Error(-19) );
 
   /* Count the number of location entries */
-  gbl_num_obs = 0;
+  num_obs = 0;
 
   /* Abort if EOF on first read from file */
   ret = Load_Line( line, obs_file, 80, "xsatcom.obs", TRUE );
@@ -1080,7 +1067,7 @@ Load_Observer_Data( void )
 	{
 	  while( (line[isr++] != ']') && (isr < 81) );
 	  if( isr < 81 )
-		gbl_num_obs++;
+		num_obs++;
 	  else
 	  {
 		fclose( obs_file );
@@ -1094,17 +1081,17 @@ Load_Observer_Data( void )
   } /* End of while( eof != EOF ) */
 
   /* Abort if no location data found */
-  if( gbl_num_obs == 0 )
+  if( num_obs == 0 )
   {
 	fclose( obs_file );
 	return( Abort_On_Error(-5) );
   }
 
   /* Allocate memory to observer database */
-  mem_alloc( (void **)&gbl_obs_data,
-	  sizeof(observer_status_t) * (size_t)gbl_num_obs,
-	  _("for gbl_obs_data in Load_Observer_Data()") );
-  if( gbl_obs_data == NULL ) return( "!OK" );
+  mem_alloc( (void **)&observer_data,
+	  sizeof(observer_status_t) * (size_t)num_obs,
+	  _("for observer_data in Load_Observer_Data()") );
+  if( observer_data == NULL ) return( "!OK" );
 
   /* Read a line from xsatcom.obs */
   rewind( obs_file );
@@ -1113,7 +1100,7 @@ Load_Observer_Data( void )
 	return( Abort_On_Error(-4) );
 
   /* Read observer data into buffer */
-  for( idx = 0; idx < gbl_num_obs; idx++ )
+  for( idx = 0; idx < num_obs; idx++ )
   {
 	/* Look for a data block name */
 	do
@@ -1135,8 +1122,8 @@ Load_Observer_Data( void )
 			line[NAME_SIZE - 2] = '~';
 			line[NAME_SIZE - 1] = '\0';
 		  }
-		  Strlcpy( gbl_obs_data[idx].loc_name, &line[1],
-			  sizeof(gbl_obs_data[idx].loc_name) );
+		  Strlcpy( observer_data[idx].loc_name, &line[1],
+			  sizeof(observer_data[idx].loc_name) );
 
 		} /* End of if( isr < 81 ) */
 
@@ -1153,101 +1140,101 @@ Load_Observer_Data( void )
 	/* Break if ']' found in line */
 	while( (isr == 1) || (isr == 81) );
 
-	ClearFlag( LOC_ENTERED | POSITION_ENTERED );
+		  ClearFlag( LOC_ENTERED | POSITION_ENTERED );
 
-	/* Set default values for missing items */
-	gbl_obs_data[idx].obs_geodetic.lon = 0.;
-	gbl_obs_data[idx].obs_geodetic.lat = 0.;
-	gbl_obs_data[idx].obs_geodetic.hgt = 0.0;
-	gbl_obs_data[idx].grid_loc[0] = '\0';
+		  /* Set default values for missing items */
+		  observer_data[idx].obs_geodetic.lon = 0.;
+		  observer_data[idx].obs_geodetic.lat = 0.;
+		  observer_data[idx].obs_geodetic.hgt = 0.0;
+		  observer_data[idx].grid_loc[0] = '\0';
 
-	/* Read items from location data block till next block name */
-	while( (line[0] != '[') )
-	{
-	  if( strncmp(line, "lon", 3) == 0 ) /* Read lon. */
-	  {
-		SetFlag( POSITION_ENTERED );
-		gbl_obs_data[idx].obs_geodetic.lon =
-		  Radians( Atof(&line[3]) );
-	  }
-	  else if( strncmp(line, "lat", 3) == 0 ) /* Read lat. */
-	  {
-		SetFlag( POSITION_ENTERED );
-		gbl_obs_data[idx].obs_geodetic.lat =
-		  Radians( Atof(&line[3]) );
-	  }
-	  else if( strncmp(line, "height", 6) == 0 ) /* Read height */
-		gbl_obs_data[idx].obs_geodetic.hgt =
-		  Atof(&line[6])/1000.0;
-	  else if( strncmp(line, "QTHloc", 6) == 0 ) /* Read QTH loc. */
-	  {
-		SetFlag( LOC_ENTERED );
-		isr = 6;
+		  /* Read items from location data block till next block name */
+		  while( (line[0] != '[') )
+		  {
+			if( strncmp(line, "lon", 3) == 0 ) /* Read lon. */
+			{
+			  SetFlag( POSITION_ENTERED );
+			  observer_data[idx].obs_geodetic.lon =
+				Radians( Atof(&line[3]) );
+			}
+			else if( strncmp(line, "lat", 3) == 0 ) /* Read lat. */
+			{
+			  SetFlag( POSITION_ENTERED );
+			  observer_data[idx].obs_geodetic.lat =
+				Radians( Atof(&line[3]) );
+			}
+			else if( strncmp(line, "height", 6) == 0 ) /* Read height */
+			  observer_data[idx].obs_geodetic.hgt =
+				Atof(&line[6])/1000.0;
+			else if( strncmp(line, "QTHloc", 6) == 0 ) /* Read QTH loc. */
+			{
+			  SetFlag( LOC_ENTERED );
+			  isr = 6;
 
-		/* Reject spaces after 'QTHloc' identifier */
-		while( (line[isr] == ' ') && (isr < 79) )
-		  isr++;
-		Strlcpy( gbl_obs_data[idx].grid_loc, &line[isr],
-			sizeof(gbl_obs_data[idx].grid_loc) );
-	  }
+			  /* Reject spaces after 'QTHloc' identifier */
+			  while( (line[isr] == ' ') && (isr < 79) )
+				isr++;
+			  Strlcpy( observer_data[idx].grid_loc, &line[isr],
+				  sizeof(observer_data[idx].grid_loc) );
+			}
 
-	  /* Read a line, return at EOF */
-	  ret = Load_Line( line, obs_file, 80, "xsatcom.obs", FALSE );
-	  if( ret == EOF_NORM )
-		break;
-	  if( ret != SUCCESS )
-		return( Abort_On_Error(-1) );
+			/* Read a line, return at EOF */
+			ret = Load_Line( line, obs_file, 80, "xsatcom.obs", FALSE );
+			if( ret == EOF_NORM )
+			  break;
+			if( ret != SUCCESS )
+			  return( Abort_On_Error(-1) );
 
-	} /* End of while( line[0] != '[' ) */
+		  } /* End of while( line[0] != '[' ) */
 
-	/* If Grid Locator and Position data are specified, */
-	/* counter-check Grid Locator and exit on mismatch  */
-	if( isFlagSet(LOC_ENTERED) &&
-		isFlagSet(POSITION_ENTERED) )
-	{
-	  lon = Degrees( gbl_obs_data[idx].obs_geodetic.lon );
-	  if( lon > 180 ) lon -= 360;
+		  /* If Grid Locator and Position data are specified, */
+		  /* counter-check Grid Locator and exit on mismatch  */
+		  if( isFlagSet(LOC_ENTERED) &&
+			  isFlagSet(POSITION_ENTERED) )
+		  {
+			lon = Degrees( observer_data[idx].obs_geodetic.lon );
+			if( lon > 180 ) lon -= 360;
 
-	  Position_to_Grid_Locator(
-		  lon,
-		  Degrees( gbl_obs_data[idx].obs_geodetic.lat ),
-		  name );
-	  /* Abort if Grid Locator does not agree with position */
-	  if( strncmp( gbl_obs_data[idx].grid_loc, name, 6) != 0 )
-	  {
-		fprintf( stderr,
-			_("xsatcom: Grid Locator mismatch with observer location: %s %s\n"),
-			gbl_obs_data[idx].grid_loc, name );
-		return( Abort_On_Error(-7) );
-	  }
-	}
-	/* If only Grid Locator is specified, calculate Position */
-	else if( isFlagSet(LOC_ENTERED) &&
-		isFlagClear(POSITION_ENTERED) )
-	{
-	  Grid_Locator_to_Position( gbl_obs_data[idx].grid_loc,
-		  &gbl_obs_data[idx].obs_geodetic.lon,
-		  &gbl_obs_data[idx].obs_geodetic.lat );
-	  gbl_obs_data[idx].obs_geodetic.lon =
-		Radians(gbl_obs_data[idx].obs_geodetic.lon);
-	  gbl_obs_data[idx].obs_geodetic.lat =
-		Radians(gbl_obs_data[idx].obs_geodetic.lat);
-	}
-	/* If only Position is specified, calculate Grid Locator */
-	else if( isFlagSet(POSITION_ENTERED) &&
-		isFlagClear(LOC_ENTERED) )
-	  Position_to_Grid_Locator( Degrees(gbl_obs_data[idx].obs_geodetic.lon),
-		  Degrees(gbl_obs_data[idx].obs_geodetic.lat),
-		  gbl_obs_data[idx].grid_loc );
+			Position_to_Grid_Locator(
+				lon,
+				Degrees( observer_data[idx].obs_geodetic.lat ),
+				name );
+			/* Abort if Grid Locator does not agree with position */
+			if( strncmp( observer_data[idx].grid_loc, name, 6) != 0 )
+			{
+			  fprintf( stderr,
+				  _("xsatcom: Grid Locator mismatch with observer location: %s %s\n"),
+				  observer_data[idx].grid_loc, name );
+			  return( Abort_On_Error(-7) );
+			}
+		  }
+		  /* If only Grid Locator is specified, calculate Position */
+		  else if( isFlagSet(LOC_ENTERED) &&
+			  isFlagClear(POSITION_ENTERED) )
+		  {
+			Grid_Locator_to_Position( observer_data[idx].grid_loc,
+				&observer_data[idx].obs_geodetic.lon,
+				&observer_data[idx].obs_geodetic.lat );
+			observer_data[idx].obs_geodetic.lon =
+			  Radians(observer_data[idx].obs_geodetic.lon);
+			observer_data[idx].obs_geodetic.lat =
+			  Radians(observer_data[idx].obs_geodetic.lat);
+		  }
+		  /* If only Position is specified, calculate Grid Locator */
+		  else if( isFlagSet(POSITION_ENTERED) &&
+			  isFlagClear(LOC_ENTERED) )
+			Position_to_Grid_Locator( Degrees(observer_data[idx].obs_geodetic.lon),
+				Degrees(observer_data[idx].obs_geodetic.lat),
+				observer_data[idx].grid_loc );
 
-	/* Do some sanity checking on data, abort on error */
-	if( (fabs(gbl_obs_data[idx].obs_geodetic.lon) > twopi) ||
-		(fabs(gbl_obs_data[idx].obs_geodetic.lat) >  pio2) ||
-		(gbl_obs_data[idx].obs_geodetic.hgt > 15.0) ||
-		(gbl_obs_data[idx].obs_geodetic.hgt < -0.5) )
-	  return( Abort_On_Error(-6) );
+		  /* Do some sanity checking on data, abort on error */
+		  if( (fabs(observer_data[idx].obs_geodetic.lon) > twopi) ||
+			  (fabs(observer_data[idx].obs_geodetic.lat) >  pio2) ||
+			  (observer_data[idx].obs_geodetic.hgt > 15.0) ||
+			  (observer_data[idx].obs_geodetic.hgt < -0.5) )
+			return( Abort_On_Error(-6) );
 
-  } /* End of for( idx = 0; idx < gbl_num_obs; idx++ ) */
+  } /* End of for( idx = 0; idx < num_obs; idx++ ) */
 
   fclose( obs_file );
 
@@ -1273,13 +1260,13 @@ Load_Observer_Set( char *loc_name, observer_status_t *obs_status )
 	  sizeof(obs_status->loc_name) );
 
   /* Look for a matching observer name in database */
-  for( idx = 0; idx < gbl_num_obs; idx++ )
+  for( idx = 0; idx < num_obs; idx++ )
   {
-	if( strncmp(gbl_obs_data[idx].loc_name, loc_name, strlen(loc_name)) == 0 )
+	if( strncmp(observer_data[idx].loc_name, loc_name, strlen(loc_name)) == 0 )
 	{
 	  /* Load TLE set on match */
-	  *obs_status = gbl_obs_data[idx];
-	  gbl_obs_idx = idx;
+	  *obs_status = observer_data[idx];
+	  obs_idx = idx;
 	  break;
 	}
   }
@@ -1287,8 +1274,8 @@ Load_Observer_Set( char *loc_name, observer_status_t *obs_status )
   /* If no matching name, load 1st observer set as default */
   if( strcmp(obs_status->loc_name, "") == 0 )
   {
-	*obs_status = gbl_obs_data[0];
-	gbl_obs_idx = 0;
+	*obs_status = observer_data[0];
+	obs_idx = 0;
   }
 
 } /* End of Load_Observer_Set() */
