@@ -1,16 +1,4 @@
-/*  input.h
- *
- *  Functions to do file i/o operations and carry out
- *  checking and preprocessing on data, mostly TLE sets,
- *  observer location and satellite databases
- */
-
 /*
- *  xsatcom: A X/GTK+ application to track satellites using the
- *  NORAD SGP4/SDP4 orbit calculation routines. The moon and sun
- *  are also tracked.
- *
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 2 of
@@ -28,7 +16,6 @@
 #define INPUT_H	1
 
 #include "common.h"
-#include "support.h"
 
 #endif
 
