@@ -1,14 +1,4 @@
-/*  mode.h
- *
- *  Functions used for running xsatcom in different 'modes'
- */
-
 /*
- *  xsatcom: A X/GTK+ application to track satellites using the
- *  NORAD SGP4/SDP4 orbit calculation routines. The moon and sun
- *  are also tracked.
- *
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 2 of
@@ -27,7 +17,6 @@
 
 #include "common.h"
 #include "interface.h"
-#include "support.h"
 #include "callbacks.h"
 
 #endif
