@@ -1,15 +1,4 @@
-/* plots.h
- *
- * Code for plotting graphs of structure
- * data (VSWR, impedance, gain etc)
- */
-
 /*
- *  xsatcom: A X/GTK+ application to track satellites using the
- *  NORAD SGP4/SDP4 orbit calculation routines. The moon and sun
- *  are also tracked.
- *
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 2 of
@@ -27,7 +16,6 @@
 #define PLOTS_H	1
 
 #include "common.h"
-#include "support.h"
 
 #endif
 
