@@ -1,15 +1,4 @@
-/*  rotor.h
- *
- *  Functions to send and receive data from the
- *  Yaesu GS-232 Az-El antenna rotor Controller
- */
-
 /*
- *  Xsatcom: A X/GTK+ Application to track satellites using the
- *  NORAD SGP4/SDP4 orbit calculation routines. The moon and sun
- *  are also tracked.
- *
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 2 of
@@ -27,7 +16,6 @@
 #define ROTOR_H	1
 
 #include "common.h"
-#include "support.h"
 
 #endif
 
