@@ -33,76 +33,82 @@
  *       ----------------------------------------------------------------      */
 
 #include "sgp4unit.h"
+#include "shared.h"
 
 extern rc_data_t rc_data;
 
 /* ----------- local functions - only ever used internally by sgp4 ---------- */
-static void dpper(
- double e3,     double ee2,    double peo,     double pgho,   double pho,
- double pinco,  double plo,    double se2,     double se3,    double sgh2,
- double sgh3,   double sgh4,   double sh2,     double sh3,    double si2,
- double si3,    double sl2,    double sl3,     double sl4,    double t,
- double xgh2,   double xgh3,   double xgh4,    double xh2,    double xh3,
- double xi2,    double xi3,    double xl2,     double xl3,    double xl4,
- double zmol,   double zmos,   char init,      double *ep,    double *inclp,
- double *nodep,  double *argpp, double *mp );
+  static void
+dpper(
+	double e3,     double ee2,    double peo,     double pgho,   double pho,
+	double pinco,  double plo,    double se2,     double se3,    double sgh2,
+	double sgh3,   double sgh4,   double sh2,     double sh3,    double si2,
+	double si3,    double sl2,    double sl3,     double sl4,    double t,
+	double xgh2,   double xgh3,   double xgh4,    double xh2,    double xh3,
+	double xi2,    double xi3,    double xl2,     double xl3,    double xl4,
+	double zmol,   double zmos,   char init,      double *ep,    double *inclp,
+	double *nodep,  double *argpp, double *mp );
 
-static void dscom(
- double epoch,  double ep,     double argpp,   double tc,     double inclp,
- double nodep,  double np,
- double *snodm, double *cnodm, double *sinim,  double *cosim, double *sinomm,
- double *cosomm,double *day,   double *e3,     double *ee2,   double *em,
- double *emsq,  double *gam,   double *peo,    double *pgho,  double *pho,
- double *pinco, double *plo,   double *rtemsq, double *se2,   double *se3,
- double *sgh2,  double *sgh3,  double *sgh4,   double *sh2,   double *sh3,
- double *si2,   double *si3,   double *sl2,    double *sl3,   double *sl4,
- double *s1,    double *s2,    double *s3,     double *s4,    double *s5,
- double *s6,    double *s7,    double *ss1,    double *ss2,   double *ss3,
- double *ss4,   double *ss5,   double *ss6,    double *ss7,   double *sz1,
- double *sz2,   double *sz3,   double *sz11,   double *sz12,  double *sz13,
- double *sz21,  double *sz22,  double *sz23,   double *sz31,  double *sz32,
- double *sz33,  double *xgh2,  double *xgh3,   double *xgh4,  double *xh2,
- double *xh3,   double *xi2,   double *xi3,    double *xl2,   double *xl3,
- double *xl4,   double *nm,    double *z1,     double *z2,    double *z3,
- double *z11,   double *z12,   double *z13,    double *z21,   double *z22,
- double *z23,   double *z31,   double *z32,    double *z33,   double *zmol,
- double *zmos );
+  static void
+dscom(
+	double epoch,  double ep,     double argpp,   double tc,     double inclp,
+	double nodep,  double np,
+	double *snodm, double *cnodm, double *sinim,  double *cosim, double *sinomm,
+	double *cosomm,double *day,   double *e3,     double *ee2,   double *em,
+	double *emsq,  double *gam,   double *peo,    double *pgho,  double *pho,
+	double *pinco, double *plo,   double *rtemsq, double *se2,   double *se3,
+	double *sgh2,  double *sgh3,  double *sgh4,   double *sh2,   double *sh3,
+	double *si2,   double *si3,   double *sl2,    double *sl3,   double *sl4,
+	double *s1,    double *s2,    double *s3,     double *s4,    double *s5,
+	double *s6,    double *s7,    double *ss1,    double *ss2,   double *ss3,
+	double *ss4,   double *ss5,   double *ss6,    double *ss7,   double *sz1,
+	double *sz2,   double *sz3,   double *sz11,   double *sz12,  double *sz13,
+	double *sz21,  double *sz22,  double *sz23,   double *sz31,  double *sz32,
+	double *sz33,  double *xgh2,  double *xgh3,   double *xgh4,  double *xh2,
+	double *xh3,   double *xi2,   double *xi3,    double *xl2,   double *xl3,
+	double *xl4,   double *nm,    double *z1,     double *z2,    double *z3,
+	double *z11,   double *z12,   double *z13,    double *z21,   double *z22,
+	double *z23,   double *z31,   double *z32,    double *z33,   double *zmol,
+	double *zmos );
 
-static void dsinit(
- double cosim,  double emsq,   double argpo,   double s1,     double s2,
- double s3,     double s4,     double s5,      double sinim,  double ss1,
- double ss2,    double ss3,    double ss4,     double ss5,    double sz1,
- double sz3,    double sz11,   double sz13,    double sz21,   double sz23,
- double sz31,   double sz33,   double t,       double tc,     double gsto,
- double mo,     double mdot,   double no,      double nodeo,  double nodedot,
- double xpidot, double z1,     double z3,      double z11,    double z13,
- double z21,    double z23,    double z31,     double z33,    double ecco,
- double eccsq,  double *em,    double *argpm,  double *inclm, double *mm,
- double *nm,    double *nodem,
- int *irez,
- double *atime, double *d2201, double *d2211,  double *d3210, double *d3222,
- double *d4410, double *d4422, double *d5220,  double *d5232, double *d5421,
- double *d5433, double *dedt,  double *didt,   double *dmdt,  double *dndt,
- double *dnodt, double *domdt, double *del1,   double *del2,  double *del3,
- double *xfact, double *xlamo, double *xli,    double *xni );
+  static void
+dsinit(
+	double cosim,  double emsq,   double argpo,   double s1,     double s2,
+	double s3,     double s4,     double s5,      double sinim,  double ss1,
+	double ss2,    double ss3,    double ss4,     double ss5,    double sz1,
+	double sz3,    double sz11,   double sz13,    double sz21,   double sz23,
+	double sz31,   double sz33,   double t,       double tc,     double gsto,
+	double mo,     double mdot,   double no,      double nodeo,  double nodedot,
+	double xpidot, double z1,     double z3,      double z11,    double z13,
+	double z21,    double z23,    double z31,     double z33,    double ecco,
+	double eccsq,  double *em,    double *argpm,  double *inclm, double *mm,
+	double *nm,    double *nodem,
+	int *irez,
+	double *atime, double *d2201, double *d2211,  double *d3210, double *d3222,
+	double *d4410, double *d4422, double *d5220,  double *d5232, double *d5421,
+	double *d5433, double *dedt,  double *didt,   double *dmdt,  double *dndt,
+	double *dnodt, double *domdt, double *del1,   double *del2,  double *del3,
+	double *xfact, double *xlamo, double *xli,    double *xni );
 
-static void dspace(
- int irez,
- double d2201,  double d2211,  double d3210,   double d3222,  double d4410,
- double d4422,  double d5220,  double d5232,   double d5421,  double d5433,
- double dedt,   double del1,   double del2,    double del3,   double didt,
- double dmdt,   double dnodt,  double domdt,   double argpo,  double argpdot,
- double t,      double tc,     double gsto,    double xfact,  double xlamo,
- double no,
- double *atime, double *em,    double *argpm,  double *inclm, double *xli,
- double *mm,    double *xni,   double *nodem,  double *dndt,  double *nm );
+  static void
+dspace(
+	int irez,
+	double d2201,  double d2211,  double d3210,   double d3222,  double d4410,
+	double d4422,  double d5220,  double d5232,   double d5421,  double d5433,
+	double dedt,   double del1,   double del2,    double del3,   double didt,
+	double dmdt,   double dnodt,  double domdt,   double argpo,  double argpdot,
+	double t,      double tc,     double gsto,    double xfact,  double xlamo,
+	double no,
+	double *atime, double *em,    double *argpm,  double *inclm, double *xli,
+	double *mm,    double *xni,   double *nodem,  double *dndt,  double *nm );
 
-static void initl(
- double ecco,   double epoch,  double inclo,   double *no,
- char *method,
- double *ainv,  double *ao,    double *con41,  double *con42, double *cosio,
- double *cosio2,double *eccsq, double *omeosq, double *posq,
- double *rp,    double *rteosq,double *sinio , double *gsto );
+  static void
+initl(
+	double ecco,   double epoch,  double inclo,   double *no,
+	char *method,
+	double *ainv,  double *ao,    double *con41,  double *con42, double *cosio,
+	double *cosio2,double *eccsq, double *omeosq, double *posq,
+	double *rp,    double *rteosq,double *sinio , double *gsto );
 
 /* -----------------------------------------------------------------------------
  *
@@ -171,15 +177,16 @@ static void initl(
  *    vallado, crawford, hujsak, kelso  2006
  ----------------------------------------------------------------------------*/
 
-static void dpper(
- double e3,     double ee2,    double peo,     double pgho,   double pho,
- double pinco,  double plo,    double se2,     double se3,    double sgh2,
- double sgh3,   double sgh4,   double sh2,     double sh3,    double si2,
- double si3,    double sl2,    double sl3,     double sl4,    double t,
- double xgh2,   double xgh3,   double xgh4,    double xh2,    double xh3,
- double xi2,    double xi3,    double xl2,     double xl3,    double xl4,
- double zmol,   double zmos,   char init,      double *ep,    double *inclp,
- double *nodep,  double *argpp, double *mp )
+  static void
+dpper(
+	double e3,     double ee2,    double peo,     double pgho,   double pho,
+	double pinco,  double plo,    double se2,     double se3,    double sgh2,
+	double sgh3,   double sgh4,   double sh2,     double sh3,    double si2,
+	double si3,    double sl2,    double sl3,     double sl4,    double t,
+	double xgh2,   double xgh3,   double xgh4,    double xh2,    double xh3,
+	double xi2,    double xi3,    double xl2,     double xl3,    double xl4,
+	double zmol,   double zmos,   char init,      double *ep,    double *inclp,
+	double *nodep,  double *argpp, double *mp )
 {
   /* --------------------- local variables ------------------------ */
   double f2,    f3,    pe,    pgh,   ph,   pinc, pl ,
@@ -347,26 +354,27 @@ static void dpper(
  *    vallado, crawford, hujsak, kelso  2006
  ----------------------------------------------------------------------------*/
 
-static void dscom(
- double epoch,  double ep,     double argpp,   double tc,     double inclp,
- double nodep,  double np,
- double *snodm, double *cnodm, double *sinim,  double *cosim, double *sinomm,
- double *cosomm,double *day,   double *e3,     double *ee2,   double *em,
- double *emsq,  double *gam,   double *peo,    double *pgho,  double *pho,
- double *pinco, double *plo,   double *rtemsq, double *se2,   double *se3,
- double *sgh2,  double *sgh3,  double *sgh4,   double *sh2,   double *sh3,
- double *si2,   double *si3,   double *sl2,    double *sl3,   double *sl4,
- double *s1,    double *s2,    double *s3,     double *s4,    double *s5,
- double *s6,    double *s7,    double *ss1,    double *ss2,   double *ss3,
- double *ss4,   double *ss5,   double *ss6,    double *ss7,   double *sz1,
- double *sz2,   double *sz3,   double *sz11,   double *sz12,  double *sz13,
- double *sz21,  double *sz22,  double *sz23,   double *sz31,  double *sz32,
- double *sz33,  double *xgh2,  double *xgh3,   double *xgh4,  double *xh2,
- double *xh3,   double *xi2,   double *xi3,    double *xl2,   double *xl3,
- double *xl4,   double *nm,    double *z1,     double *z2,    double *z3,
- double *z11,   double *z12,   double *z13,    double *z21,   double *z22,
- double *z23,   double *z31,   double *z32,    double *z33,   double *zmol,
- double *zmos )
+  static void
+dscom(
+	double epoch,  double ep,     double argpp,   double tc,     double inclp,
+	double nodep,  double np,
+	double *snodm, double *cnodm, double *sinim,  double *cosim, double *sinomm,
+	double *cosomm,double *day,   double *e3,     double *ee2,   double *em,
+	double *emsq,  double *gam,   double *peo,    double *pgho,  double *pho,
+	double *pinco, double *plo,   double *rtemsq, double *se2,   double *se3,
+	double *sgh2,  double *sgh3,  double *sgh4,   double *sh2,   double *sh3,
+	double *si2,   double *si3,   double *sl2,    double *sl3,   double *sl4,
+	double *s1,    double *s2,    double *s3,     double *s4,    double *s5,
+	double *s6,    double *s7,    double *ss1,    double *ss2,   double *ss3,
+	double *ss4,   double *ss5,   double *ss6,    double *ss7,   double *sz1,
+	double *sz2,   double *sz3,   double *sz11,   double *sz12,  double *sz13,
+	double *sz21,  double *sz22,  double *sz23,   double *sz31,  double *sz32,
+	double *sz33,  double *xgh2,  double *xgh3,   double *xgh4,  double *xh2,
+	double *xh3,   double *xi2,   double *xi3,    double *xl2,   double *xl3,
+	double *xl4,   double *nm,    double *z1,     double *z2,    double *z3,
+	double *z11,   double *z12,   double *z13,    double *z21,   double *z22,
+	double *z23,   double *z31,   double *z32,    double *z33,   double *zmol,
+	double *zmos )
 {
   /* --------------------- local variables ------------------------ */
   int lsflg;
@@ -613,7 +621,8 @@ static void dscom(
 *    vallado, crawford, hujsak, kelso  2006
 ----------------------------------------------------------------------------*/
 
-static void dsinit(
+  static void
+dsinit(
 	double cosim,  double emsq,   double argpo,   double s1,     double s2,
 	double s3,     double s4,     double s5,      double sinim,  double ss1,
 	double ss2,    double ss3,    double ss4,     double ss5,    double sz1,
@@ -888,16 +897,17 @@ static void dsinit(
  *    vallado, crawford, hujsak, kelso  2006
 ----------------------------------------------------------------------------*/
 
-static void dspace(
+  static void
+dspace(
 	int irez,
 	double d2201,  double d2211,  double d3210,   double d3222,  double d4410,
 	double d4422,  double d5220,  double d5232,   double d5421,  double d5433,
 	double dedt,   double del1,   double del2,    double del3,   double didt,
 	double dmdt,   double dnodt,  double domdt,   double argpo,  double argpdot,
 	double t,      double tc,     double gsto,    double xfact,  double xlamo,
-	double no,
-	double *atime, double *em,    double *argpm,  double *inclm, double *xli,
-	double *mm,    double *xni,   double *nodem,  double *dndt,  double *nm )
+	double no,     double *atime, double *em,    double *argpm,  double *inclm,
+	double *xli,   double *mm,    double *xni,   double *nodem,  double *dndt,
+	double *nm )
 {
   double  ft, theta, fasx2, fasx4, fasx6, step2, stepn, stepp;
 
@@ -934,42 +944,36 @@ static void dspace(
   //   the specific changes are unknown because the original code was so convoluted
 
   ft     = 0.0;
-  *atime = 0.0;
   if (irez != 0)
   {
 	int iretn, iret;
 	double delt, x2li, x2omi, xl, xldot = 0.0, xnddt = 0.0, xndt = 0.0, xomi;
 
-	if ((*atime == 0.0) || ((t >= 0.0) && (*atime < 0.0)) ||
-		((t < 0.0) && (*atime >= 0.0)))
+	if( (*atime == 0.0) ||
+		( (t >= 0.0) && (*atime <  0.0) ) ||
+		( (t <  0.0) && (*atime >= 0.0) ) )
 	{
-	  if (t >= 0.0)
-		delt = stepp;
-	  else
-		delt = stepn;
 	  *atime = 0.0;
 	  *xni   = no;
 	  *xli   = xlamo;
 	}
+
+	if (t >= 0.0)
+	  delt = stepp;
+	else
+	  delt = stepn;
+
 	iretn = 381; // added for do loop
 	iret  =   0; // added for loop
 	while (iretn == 381)
 	{
 	  if ((fabs(t) < fabs(*atime)) || (iret == 351))
 	  {
-		if (t >= 0.0)
-		  delt = stepn;
-		else
-		  delt = stepp;
 		iret  = 351;
 		iretn = 381;
 	  }
 	  else
 	  {
-		if (t > 0.0)  // error if prev if has atime:=0.0 and t:=0.0 (ge)
-		  delt = stepp;
-		else
-		  delt = stepn;
 		if (fabs(t - *atime) >= stepp)
 		{
 		  iret  = 0;
@@ -1092,7 +1096,51 @@ static void dspace(
  *    vallado, crawford, hujsak, kelso  2006
  ----------------------------------------------------------------------------*/
 
-static void initl(
+/* -----------------------------------------------------------------------------
+ *
+ *                           function gstime
+ *
+ *  this function finds the greenwich sidereal time.
+ *
+ *  author        : david vallado                  719-573-2600    1 mar 2001
+ *
+ *  inputs          description                    range / units
+ *    jdut1       - julian date in ut1             days from 4713 bc
+ *
+ *  outputs       :
+ *    gstime      - greenwich sidereal time        0 to 2pi rad
+ *
+ *  locals        :
+ *    temp        - temporary variable for doubles   rad
+ *    tut1        - julian centuries from the
+ *                  jan 1, 2000 12 h epoch (ut1)
+ *
+ *  coupling      :
+ *    none
+ *
+ *  references    :
+ *    vallado       2004, 191, eq 3-45
+ * --------------------------------------------------------------------------- */
+
+  static double
+gstime( double jdut1 )
+{
+  const double deg2rad = pi / 180.0;
+  double       temp, tut1;
+
+  tut1 = (jdut1 - 2451545.0) / 36525.0;
+  temp = -6.2e-6* tut1 * tut1 * tut1 + 0.093104 * tut1 * tut1 +
+	(876600.0*3600 + 8640184.812866) * tut1 + 67310.54841;  // sec
+  temp = fmod(temp * deg2rad / 240.0, twopi); //360/86400 = 1/240, to deg, to rad
+
+  // ------------------------ check quadrants ---------------------
+  if (temp < 0.0) temp += twopi;
+
+  return temp;
+}  // end gstime
+
+  static void
+initl(
 	double ecco,   double epoch,   double inclo,   double *no,
 	char *method,
 	double *ainv,  double *ao,     double *con41,  double *con42,
@@ -1213,20 +1261,21 @@ static void initl(
 *    vallado, crawford, hujsak, kelso  2006
 ----------------------------------------------------------------------------*/
 
-int sgp4init( const int satn, const double epoch, elem_set_t *elem_set )
+  int
+sgp4init( const int satn, const double epoch, element_set_t *elem_set )
 {
   /* --------------------- local variables ------------------------ */
   double
 	ao  , ainv  , con42 , cosio , sinio, cosio2, eccsq ,
-  omeosq, posq  , rp    , rteosq, cnodm, snodm , cosim ,
-  sinim , cosomm, sinomm, day   , dndt , em    , emsq  ,
-  gam   , argpm , nodem , inclm , mm   , nm    , rtemsq,
-  s1    , s2    , s3    , s4    , s5   , s6    , s7    ,
-  ss1   , ss2   , ss3   , ss4   , ss5  , ss6   , ss7   ,
-  sz1   , sz2   , sz3   , sz11  , sz12 , sz13  , sz21  ,
-  sz22  , sz23  , sz31  , sz32  , sz33 , z1    , z2    ,
-  z3    , z11   , z12   , z13   , z21  , z22   , z23   ,
-  z31   , z32   , z33   , qzms2t, ss;
+		omeosq, posq  , rp    , rteosq, cnodm, snodm , cosim ,
+		sinim , cosomm, sinomm, day   , dndt , em    , emsq  ,
+		gam   , argpm , nodem , inclm , mm   , nm    , rtemsq,
+		s1    , s2    , s3    , s4    , s5   , s6    , s7    ,
+		ss1   , ss2   , ss3   , ss4   , ss5  , ss6   , ss7   ,
+		sz1   , sz2   , sz3   , sz11  , sz12 , sz13  , sz21  ,
+		sz22  , sz23  , sz31  , sz32  , sz33 , z1    , z2    ,
+		z3    , z11   , z12   , z13   , z21  , z22   , z23   ,
+		z31   , z32   , z33   , qzms2t, ss;
 
   kinetics_t kin;
 
@@ -1293,8 +1342,8 @@ int sgp4init( const int satn, const double epoch, elem_set_t *elem_set )
   {
 	double
 	  cc2  , cc3   , coef  , coef1 , cosio4, eeta ,
-	  etasq, perige, pinvsq, psisq , qzms24, sfour,
-	  temp1, temp2 , temp3 , tsi   , xpidot, xhdot1;
+		   etasq, perige, pinvsq, psisq , qzms24, sfour,
+		   temp1, temp2 , temp3 , tsi   , xpidot, xhdot1;
 
 	elem_set->isimp = 0;
 	if (rp < (220.0 / rc_data.radiusearthkm + 1.0))
@@ -1315,7 +1364,7 @@ int sgp4init( const int satn, const double epoch, elem_set_t *elem_set )
 	pinvsq = 1.0 / posq;
 
 	tsi  = 1.0 / (ao - sfour);
-	elem_set->eta  = ao * elem_set->ecco * tsi;
+	elem_set->eta = ao * elem_set->ecco * tsi;
 	etasq = elem_set->eta * elem_set->eta;
 	eeta  = elem_set->ecco * elem_set->eta;
 	psisq = fabs(1.0 - etasq);
@@ -1324,16 +1373,16 @@ int sgp4init( const int satn, const double epoch, elem_set_t *elem_set )
 	cc2   = coef1 * elem_set->no * (ao * (1.0 + 1.5 * etasq + eeta *
 		  (4.0 + etasq)) + 0.375 * rc_data.j2 * tsi / psisq * elem_set->con41 *
 		(8.0 + 3.0 * etasq * (8.0 + etasq)));
-	elem_set->cc1   = elem_set->bstar * cc2;
+	elem_set->cc1 = elem_set->bstar * cc2;
 	cc3   = 0.0;
 	if (elem_set->ecco > 1.0e-4)
 	  cc3 = -2.0 * coef * tsi * rc_data.j3oj2 * elem_set->no * sinio / elem_set->ecco;
 	elem_set->x1mth2 = 1.0 - cosio2;
-	elem_set->cc4    = 2.0* elem_set->no * coef1 * ao * omeosq *
+	elem_set->cc4 = 2.0* elem_set->no * coef1 * ao * omeosq *
 	  (elem_set->eta * (2.0 + 0.5 * etasq) + elem_set->ecco *
 	   (0.5 + 2.0 * etasq) - rc_data.j2 * tsi / (ao * psisq) *
 	   (-3.0 * elem_set->con41 * (1.0 - 2.0 * eeta + etasq *
-							   (1.5 - 0.5 * eeta)) + 0.75 * elem_set->x1mth2 *
+								  (1.5 - 0.5 * eeta)) + 0.75 * elem_set->x1mth2 *
 		(2.0 * etasq - eeta * (1.0 + etasq)) * cos(2.0 * elem_set->argpo)));
 	elem_set->cc5 = 2.0 * coef1 * ao * omeosq * (1.0 + 2.75 *
 		(etasq + eeta) + eeta * etasq);
@@ -1341,32 +1390,32 @@ int sgp4init( const int satn, const double epoch, elem_set_t *elem_set )
 	temp1  = 1.5 * rc_data.j2 * pinvsq * elem_set->no;
 	temp2  = 0.5 * temp1 * rc_data.j2 * pinvsq;
 	temp3  = -0.46875 * rc_data.j4 * pinvsq * pinvsq * elem_set->no;
-	elem_set->mdot     = elem_set->no + 0.5 * temp1 * rteosq * elem_set->con41 + 0.0625 *
+	elem_set->mdot = elem_set->no + 0.5 * temp1 * rteosq * elem_set->con41 + 0.0625 *
 	  temp2 * rteosq * (13.0 - 78.0 * cosio2 + 137.0 * cosio4);
-	elem_set->argpdot  = -0.5 * temp1 * con42 + 0.0625 * temp2 *
+	elem_set->argpdot = -0.5 * temp1 * con42 + 0.0625 * temp2 *
 	  (7.0 - 114.0 * cosio2 + 395.0 * cosio4) +
 	  temp3 * (3.0 - 36.0 * cosio2 + 49.0 * cosio4);
-	xhdot1            = -temp1 * cosio;
+	xhdot1 = -temp1 * cosio;
 	elem_set->nodedot = xhdot1 + (0.5 * temp2 * (4.0 - 19.0 * cosio2) +
 		2.0 * temp3 * (3.0 - 7.0 * cosio2)) * cosio;
-	xpidot            =  elem_set->argpdot+ elem_set->nodedot;
-	elem_set->omgcof   = elem_set->bstar * cc3 * cos(elem_set->argpo);
-	elem_set->xmcof    = 0.0;
+	xpidot =  elem_set->argpdot+ elem_set->nodedot;
+	elem_set->omgcof = elem_set->bstar * cc3 * cos(elem_set->argpo);
+	elem_set->xmcof  = 0.0;
 	if (elem_set->ecco > 1.0e-4)
 	  elem_set->xmcof = -tothrd * coef * elem_set->bstar / eeta;
 	elem_set->nodecf = 3.5 * omeosq * xhdot1 * elem_set->cc1;
 	elem_set->t2cof   = 1.5 * elem_set->cc1;
 	// sgp4fix for divide by zero with xinco = 180 deg
 	if (fabs(cosio+1.0) > 1.5e-12)
-	  elem_set->xlcof = -0.25 * rc_data.j3oj2 * sinio * (3.0 + 5.0 * cosio) /
-		(1.0 + cosio);
+	  elem_set->xlcof =
+		-0.25 * rc_data.j3oj2 * sinio * (3.0 + 5.0 * cosio) / (1.0 + cosio);
 	else
-	  elem_set->xlcof = -0.25 * rc_data.j3oj2 * sinio * (3.0 + 5.0 * cosio) /
-		temp4;
-	elem_set->aycof   = -0.5 * rc_data.j3oj2 * sinio;
-	elem_set->delmo   = pow((1.0 + elem_set->eta * cos(elem_set->mo)), 3);
-	elem_set->sinmao  = sin(elem_set->mo);
-	elem_set->x7thm1  = 7.0 * cosio2 - 1.0;
+	  elem_set->xlcof =
+		-0.25 * rc_data.j3oj2 * sinio * (3.0 + 5.0 * cosio) / temp4;
+	elem_set->aycof  = -0.5 * rc_data.j3oj2 * sinio;
+	elem_set->delmo  = pow((1.0 + elem_set->eta * cos(elem_set->mo)), 3);
+	elem_set->sinmao = sin(elem_set->mo);
+	elem_set->x7thm1 = 7.0 * cosio2 - 1.0;
 
 	/* --------------- deep space initialization ------------- */
 	if ((twopi / elem_set->no) >= 225.0)
@@ -1379,50 +1428,50 @@ int sgp4init( const int satn, const double epoch, elem_set_t *elem_set )
 	  inclm = elem_set->inclo;
 
 	  dscom(
-		 epoch, elem_set->ecco, elem_set->argpo, tc, elem_set->inclo, elem_set->nodeo,
-		 elem_set->no, &snodm, &cnodm,  &sinim, &cosim, &sinomm, &cosomm,
-		 &day, &elem_set->e3, &elem_set->ee2, &em, &emsq, &gam,
-		 &elem_set->peo,  &elem_set->pgho, &elem_set->pho, &elem_set->pinco,
-		 &elem_set->plo,  &rtemsq, &elem_set->se2, &elem_set->se3,
-		 &elem_set->sgh2, &elem_set->sgh3,   &elem_set->sgh4,
-		 &elem_set->sh2,  &elem_set->sh3,    &elem_set->si2, &elem_set->si3,
-		 &elem_set->sl2,  &elem_set->sl3,    &elem_set->sl4, &s1, &s2, &s3, &s4, &s5,
-		 &s6, &s7, &ss1, &ss2, &ss3, &ss4, &ss5, &ss6, &ss7, &sz1, &sz2, &sz3,
-		 &sz11, &sz12, &sz13, &sz21, &sz22, &sz23, &sz31, &sz32, &sz33,
-		 &elem_set->xgh2, &elem_set->xgh3, &elem_set->xgh4, &elem_set->xh2,
-		 &elem_set->xh3, &elem_set->xi2, &elem_set->xi3, &elem_set->xl2,
-		 &elem_set->xl3, &elem_set->xl4, &nm, &z1, &z2, &z3, &z11,
-		 &z12, &z13, &z21, &z22, &z23, &z31, &z32, &z33,
-		 &elem_set->zmol, &elem_set->zmos );
+		  epoch, elem_set->ecco, elem_set->argpo, tc, elem_set->inclo, elem_set->nodeo,
+		  elem_set->no, &snodm, &cnodm,  &sinim, &cosim, &sinomm, &cosomm,
+		  &day, &elem_set->e3, &elem_set->ee2, &em, &emsq, &gam,
+		  &elem_set->peo,  &elem_set->pgho, &elem_set->pho, &elem_set->pinco,
+		  &elem_set->plo,  &rtemsq, &elem_set->se2, &elem_set->se3,
+		  &elem_set->sgh2, &elem_set->sgh3,   &elem_set->sgh4,
+		  &elem_set->sh2,  &elem_set->sh3,    &elem_set->si2, &elem_set->si3,
+		  &elem_set->sl2,  &elem_set->sl3,    &elem_set->sl4, &s1, &s2, &s3, &s4, &s5,
+		  &s6, &s7, &ss1, &ss2, &ss3, &ss4, &ss5, &ss6, &ss7, &sz1, &sz2, &sz3,
+		  &sz11, &sz12, &sz13, &sz21, &sz22, &sz23, &sz31, &sz32, &sz33,
+		  &elem_set->xgh2, &elem_set->xgh3, &elem_set->xgh4, &elem_set->xh2,
+		  &elem_set->xh3, &elem_set->xi2, &elem_set->xi3, &elem_set->xl2,
+		  &elem_set->xl3, &elem_set->xl4, &nm, &z1, &z2, &z3, &z11,
+		  &z12, &z13, &z21, &z22, &z23, &z31, &z32, &z33,
+		  &elem_set->zmol, &elem_set->zmos );
 
 	  dpper(
-		 elem_set->e3, elem_set->ee2, elem_set->peo, elem_set->pgho,
-		 elem_set->pho, elem_set->pinco, elem_set->plo, elem_set->se2,
-		 elem_set->se3, elem_set->sgh2, elem_set->sgh3, elem_set->sgh4,
-		 elem_set->sh2, elem_set->sh3, elem_set->si2,  elem_set->si3,
-		 elem_set->sl2, elem_set->sl3, elem_set->sl4,  elem_set->t,
-		 elem_set->xgh2,elem_set->xgh3,elem_set->xgh4, elem_set->xh2,
-		 elem_set->xh3, elem_set->xi2, elem_set->xi3,  elem_set->xl2,
-		 elem_set->xl3, elem_set->xl4, elem_set->zmol, elem_set->zmos,
-		 elem_set->init, &elem_set->ecco, &elem_set->inclo,
-		 &elem_set->nodeo, &elem_set->argpo, &elem_set->mo );
+		  elem_set->e3, elem_set->ee2, elem_set->peo, elem_set->pgho,
+		  elem_set->pho, elem_set->pinco, elem_set->plo, elem_set->se2,
+		  elem_set->se3, elem_set->sgh2, elem_set->sgh3, elem_set->sgh4,
+		  elem_set->sh2, elem_set->sh3, elem_set->si2,  elem_set->si3,
+		  elem_set->sl2, elem_set->sl3, elem_set->sl4,  elem_set->t,
+		  elem_set->xgh2,elem_set->xgh3,elem_set->xgh4, elem_set->xh2,
+		  elem_set->xh3, elem_set->xi2, elem_set->xi3,  elem_set->xl2,
+		  elem_set->xl3, elem_set->xl4, elem_set->zmol, elem_set->zmos,
+		  elem_set->init, &elem_set->ecco, &elem_set->inclo,
+		  &elem_set->nodeo, &elem_set->argpo, &elem_set->mo );
 
 	  argpm  = 0.0;
 	  nodem  = 0.0;
 	  mm     = 0.0;
 	  dsinit(
-		 cosim, emsq, elem_set->argpo, s1, s2, s3, s4, s5, sinim, ss1, ss2, ss3, ss4,
-		 ss5, sz1, sz3, sz11, sz13, sz21, sz23, sz31, sz33, elem_set->t, tc,
-		 elem_set->gsto, elem_set->mo, elem_set->mdot, elem_set->no, elem_set->nodeo,
-		 elem_set->nodedot, xpidot, z1, z3, z11, z13, z21, z23, z31, z33,
-		 elem_set->ecco, eccsq, &em, &argpm, &inclm, &mm, &nm, &nodem,
-		 &elem_set->irez, &elem_set->atime,
-		 &elem_set->d2201, &elem_set->d2211, &elem_set->d3210, &elem_set->d3222,
-		 &elem_set->d4410, &elem_set->d4422, &elem_set->d5220, &elem_set->d5232,
-		 &elem_set->d5421, &elem_set->d5433, &elem_set->dedt,  &elem_set->didt,
-		 &elem_set->dmdt,  &dndt,         &elem_set->dnodt, &elem_set->domdt ,
-		 &elem_set->del1, &elem_set->del2, &elem_set->del3, &elem_set->xfact,
-		 &elem_set->xlamo, &elem_set->xli,   &elem_set->xni );
+		  cosim, emsq, elem_set->argpo, s1, s2, s3, s4, s5, sinim, ss1, ss2, ss3, ss4,
+		  ss5, sz1, sz3, sz11, sz13, sz21, sz23, sz31, sz33, elem_set->t, tc,
+		  elem_set->gsto, elem_set->mo, elem_set->mdot, elem_set->no, elem_set->nodeo,
+		  elem_set->nodedot, xpidot, z1, z3, z11, z13, z21, z23, z31, z33,
+		  elem_set->ecco, eccsq, &em, &argpm, &inclm, &mm, &nm, &nodem,
+		  &elem_set->irez, &elem_set->atime,
+		  &elem_set->d2201, &elem_set->d2211, &elem_set->d3210, &elem_set->d3222,
+		  &elem_set->d4410, &elem_set->d4422, &elem_set->d5220, &elem_set->d5232,
+		  &elem_set->d5421, &elem_set->d5433, &elem_set->dedt,  &elem_set->didt,
+		  &elem_set->dmdt,  &dndt,         &elem_set->dnodt, &elem_set->domdt ,
+		  &elem_set->del1, &elem_set->del2, &elem_set->del3, &elem_set->xfact,
+		  &elem_set->xlamo, &elem_set->xli,   &elem_set->xni );
 	}
 
 	/* ----------- set variables if not deep space ----------- */
@@ -1430,12 +1479,12 @@ int sgp4init( const int satn, const double epoch, elem_set_t *elem_set )
 	{
 	  double cc1sq, temp;
 
-	  cc1sq        = elem_set->cc1 * elem_set->cc1;
+	  cc1sq = elem_set->cc1 * elem_set->cc1;
 	  elem_set->d2 = 4.0 * ao * tsi * cc1sq;
-	  temp         = elem_set->d2 * tsi * elem_set->cc1 / 3.0;
+	  temp = elem_set->d2 * tsi * elem_set->cc1 / 3.0;
 	  elem_set->d3 = (17.0 * ao + sfour) * temp;
-	  elem_set->d4 = 0.5 * temp * ao * tsi * (221.0 * ao + 31.0 * sfour) *
-		elem_set->cc1;
+	  elem_set->d4 =
+		0.5 * temp * ao * tsi * (221.0 * ao + 31.0 * sfour) * elem_set->cc1;
 	  elem_set->t3cof = elem_set->d2 + 2.0 * cc1sq;
 	  elem_set->t4cof = 0.25 * (3.0 * elem_set->d3 + elem_set->cc1 *
 		  (12.0 * elem_set->d2 + 10.0 * cc1sq));
@@ -1542,16 +1591,17 @@ int sgp4init( const int satn, const double epoch, elem_set_t *elem_set )
 *    vallado, crawford, hujsak, kelso  2006
 ----------------------------------------------------------------------------*/
 
-int sgp4( elem_set_t *elem_set, double tsince,  kinetics_t *kinetics )
+  int
+sgp4( element_set_t *elem_set, double tsince,  kinetics_t *kinetics )
 {
   double
 	am    , axnl ,  aynl, cosim , coseo1 = 0.0, cosip, delm  ,
-	delomg, em   , ecose, el2   , eo1  , ep    ,
-	esine , argpm, argpp, argpdf, pl    , mrt  , sinim ,
-	sineo1 = 0.0, sinip, t2   , t3    , t4    , tem5 , temp  ,
-	tempa , tempe, templ, u     , inclm , mm   , nm    ,
-	nodem , xincp, xl   , xlm   , mp    , xmdf , nodedf,
-	nodep , tc   , dndt; //, emsq;
+		  delomg, em   , ecose, el2   , eo1  , ep    ,
+		  esine , argpm, argpp, argpdf, pl    , mrt  , sinim ,
+		  sineo1 = 0.0, sinip, t2   , t3    , t4    , tem5 , temp  ,
+		  tempa , tempe, templ, u     , inclm , mm   , nm    ,
+		  nodem , xincp, xl   , xlm   , mp    , xmdf , nodedf,
+		  nodep , tc   , dndt; //, emsq;
 
   int ktr;
 
@@ -1601,19 +1651,19 @@ int sgp4( elem_set_t *elem_set, double tsince,  kinetics_t *kinetics )
   {
 	tc = elem_set->t;
 	dspace(
-	   elem_set->irez,
-	   elem_set->d2201, elem_set->d2211,   elem_set->d3210,
-	   elem_set->d3222, elem_set->d4410,   elem_set->d4422,
-	   elem_set->d5220, elem_set->d5232,   elem_set->d5421,
-	   elem_set->d5433, elem_set->dedt,    elem_set->del1,
-	   elem_set->del2,  elem_set->del3,    elem_set->didt,
-	   elem_set->dmdt,  elem_set->dnodt,   elem_set->domdt,
-	   elem_set->argpo, elem_set->argpdot, elem_set->t, tc,
-	   elem_set->gsto,  elem_set->xfact,   elem_set->xlamo,
-	   elem_set->no,    &elem_set->atime,
-	   &em,             &argpm,            &inclm, &elem_set->xli,
-	   &mm,             &elem_set->xni,	   &nodem,
-	   &dndt,           &nm );
+		elem_set->irez,
+		elem_set->d2201, elem_set->d2211,   elem_set->d3210,
+		elem_set->d3222, elem_set->d4410,   elem_set->d4422,
+		elem_set->d5220, elem_set->d5232,   elem_set->d5421,
+		elem_set->d5433, elem_set->dedt,    elem_set->del1,
+		elem_set->del2,  elem_set->del3,    elem_set->didt,
+		elem_set->dmdt,  elem_set->dnodt,   elem_set->domdt,
+		elem_set->argpo, elem_set->argpdot, elem_set->t, tc,
+		elem_set->gsto,  elem_set->xfact,   elem_set->xlamo,
+		elem_set->no,    &elem_set->atime,
+		&em,             &argpm,            &inclm, &elem_set->xli,
+		&mm,             &elem_set->xni,	   &nodem,
+		&dndt,           &nm );
   } // if method = d
 
   if (nm <= 0.0)
@@ -1657,18 +1707,18 @@ int sgp4( elem_set_t *elem_set, double tsince,  kinetics_t *kinetics )
   if (elem_set->method == 'd')
   {
 	dpper(
-	   elem_set->e3,   elem_set->ee2,  elem_set->peo,
-	   elem_set->pgho, elem_set->pho,  elem_set->pinco,
-	   elem_set->plo,  elem_set->se2,  elem_set->se3,
-	   elem_set->sgh2, elem_set->sgh3, elem_set->sgh4,
-	   elem_set->sh2,  elem_set->sh3,  elem_set->si2,
-	   elem_set->si3,  elem_set->sl2,  elem_set->sl3,
-	   elem_set->sl4,  elem_set->t,    elem_set->xgh2,
-	   elem_set->xgh3, elem_set->xgh4, elem_set->xh2,
-	   elem_set->xh3,  elem_set->xi2,  elem_set->xi3,
-	   elem_set->xl2,  elem_set->xl3,  elem_set->xl4,
-	   elem_set->zmol, elem_set->zmos,
-	   'n', &ep, &xincp, &nodep, &argpp, &mp );
+		elem_set->e3,   elem_set->ee2,  elem_set->peo,
+		elem_set->pgho, elem_set->pho,  elem_set->pinco,
+		elem_set->plo,  elem_set->se2,  elem_set->se3,
+		elem_set->sgh2, elem_set->sgh3, elem_set->sgh4,
+		elem_set->sh2,  elem_set->sh3,  elem_set->si2,
+		elem_set->si3,  elem_set->sl2,  elem_set->sl3,
+		elem_set->sl4,  elem_set->t,    elem_set->xgh2,
+		elem_set->xgh3, elem_set->xgh4, elem_set->xh2,
+		elem_set->xh3,  elem_set->xi2,  elem_set->xi3,
+		elem_set->xl2,  elem_set->xl3,  elem_set->xl4,
+		elem_set->zmol, elem_set->zmos,
+		'n', &ep, &xincp, &nodep, &argpp, &mp );
 	if (xincp < 0.0)
 	{
 	  xincp  = -xincp;
@@ -1690,11 +1740,11 @@ int sgp4( elem_set_t *elem_set, double tsince,  kinetics_t *kinetics )
 	elem_set->aycof = -0.5*rc_data.j3oj2*sinip;
 	// sgp4fix for divide by zero for xincp = 180 deg
 	if (fabs(cosip+1.0) > 1.5e-12)
-	  elem_set->xlcof = -0.25 * rc_data.j3oj2 * sinip * (3.0 + 5.0 * cosip) /
-		(1.0 + cosip);
+	  elem_set->xlcof =
+		-0.25 * rc_data.j3oj2 * sinip * (3.0 + 5.0 * cosip) / (1.0 + cosip);
 	else
-	  elem_set->xlcof = -0.25 * rc_data.j3oj2 * sinip * (3.0 + 5.0 * cosip) /
-		temp4;
+	  elem_set->xlcof =
+		-0.25 * rc_data.j3oj2 * sinip * (3.0 + 5.0 * cosip) / temp4;
   }
   axnl = ep * cos(argpp);
   temp = 1.0 / (am * (1.0 - ep * ep));
@@ -1819,48 +1869,6 @@ int sgp4( elem_set_t *elem_set, double tsince,  kinetics_t *kinetics )
 
 }  // end sgp4
 
-/* -----------------------------------------------------------------------------
- *
- *                           function gstime
- *
- *  this function finds the greenwich sidereal time.
- *
- *  author        : david vallado                  719-573-2600    1 mar 2001
- *
- *  inputs          description                    range / units
- *    jdut1       - julian date in ut1             days from 4713 bc
- *
- *  outputs       :
- *    gstime      - greenwich sidereal time        0 to 2pi rad
- *
- *  locals        :
- *    temp        - temporary variable for doubles   rad
- *    tut1        - julian centuries from the
- *                  jan 1, 2000 12 h epoch (ut1)
- *
- *  coupling      :
- *    none
- *
- *  references    :
- *    vallado       2004, 191, eq 3-45
- * --------------------------------------------------------------------------- */
-
-double gstime( double jdut1 )
-{
-  const double deg2rad = pi / 180.0;
-  double       temp, tut1;
-
-  tut1 = (jdut1 - 2451545.0) / 36525.0;
-  temp = -6.2e-6* tut1 * tut1 * tut1 + 0.093104 * tut1 * tut1 +
-	(876600.0*3600 + 8640184.812866) * tut1 + 67310.54841;  // sec
-  temp = fmod(temp * deg2rad / 240.0, twopi); //360/86400 = 1/240, to deg, to rad
-
-  // ------------------------ check quadrants ---------------------
-  if (temp < 0.0) temp += twopi;
-
-  return temp;
-}  // end gstime
-
 /* -----------------------------------------------------------------------------
  *
  *                           function getgravconst
@@ -1891,7 +1899,8 @@ double gstime( double jdut1 )
  *    vallado, crawford, hujsak, kelso  2006
  --------------------------------------------------------------------------- */
 
-void getgravconst( void )
+  void
+getgravconst( void )
 {
   double mu;
 
@@ -1936,3 +1945,5 @@ void getgravconst( void )
 
 }   // end getgravconst
 
+/*--------------------------------------------------------------------------- */
+
