@@ -1,14 +1,4 @@
-/*  utils.h
- *
- *  Utility functions for the xsatcom application
- */
-
 /*
- *  xsatcom: A X/GTK+ application to track satellites using the
- *  NORAD SGP4/SDP4 orbit calculation routines. The moon and sun
- *  are also tracked.
- *
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 2 of
@@ -26,6 +16,12 @@
 #define UTILS_H		1
 
 #include "common.h"
-#include "support.h"
+
+/* xplanet files */
+#define XPLANET_CONFIG "config/xsatcom"
+#define XPLANET_MARKER "markers/xsatcom"
+#define XPLANET_GCARCS "arcs/xsatcom"
+#define XPLANET_SATFLE "satellites/xsatcom"
 
 #endif
+
